#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
import kss


class KssTest(unittest.TestCase):

    def test_split(self):
        text = "회사 동료 분들과 다녀왔는데 분위기도 좋고 음식도 맛있었어요 다만, 강남 토끼정이 강남 쉑쉑버거 골목길로 쭉 올라가야 하는데 다들 쉑쉑버거의 유혹에 넘어갈 뻔 했답니다 강남역 맛집 토끼정의 외부 모습."
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 3)

    def test_single_quotes(self):
        text = """여당이 내놓은 상가건물 임대차보호법 개정안, 이른바 ‘임대료 멈춤법’에 대한 논의가 급물살을 타면서 자영업자들과 임대인의 의견이 팽팽하게 맞서고 있다. 신종 코로나바이러스 감염증(코로나19) 확진자 급증세로 집합 제한·집합 금지 기간이 길어지면서 한계에 직면한 소상공인과 자영업자들 사이에서는 임대료 부담을 호소하며 "법안을 조속히 시행해 달라"는 목소리가 터져나오고 있다. 반면 임대인들은 임대료 인하를 강제화하는 것은 부당하다며 정부와 여당이 ‘나쁜 임대인(건물주)’ 프레임을 만들고 있다고 비판했다. 업계 전문가들 사이에서도 우려의 목소리가 여럿 있다. 재산권 침해 소지가 있고, 월세 수익이 끊기면 생활이 곤란해지는 ‘생계형 임대인’들이 피해를 볼 수 있는 등 또 다른 부작용이 발생할 수 있다는 것이다. 법 개정 자체만으로 상가 거래 시장이 위축될 가능성도 지적됐다."""
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 6)

    def test_quote_misalignment(self):
        # testcase from https://github.com/likejazz/korean-sentence-splitter/issues/8
        text = """부부 싸움 규칙 가운데 ‘돈 히트 언더 더 벨트’(Don’t hit under the belt)가 있다. 권투할 때 벨트 아래를 치면 반칙이듯이, 상대가 너무 아파할 만한 것을 건드리면 회복하기 어렵다. 그 부분은 사람마다 다르다."""
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 3)

        text = """안녕하십니까? 삼성전자가 11월 13일 삼성전자 서초사옥 다목적홀 5층에서 진행되는 2013 S'데이 멤버십 블루 강연회 "Challenge BLUE, 박찬호&이동우의 삶과 도전" 멤버십 블루 고객 480명을 초청한다.강연회는 삼성전자 멤버십 블루 회원들을 위해 마련된 고객 혜택 행사로 한국인 최초의 메이저리거 박찬호와 시각장애 개그맨 이동우를 초청, 그들의 삶 속에서 펼쳐진 다양한 도전기를 들을 수 있도록 마련했다."""
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 3)

        text = """삼성전자가 11월 13일 삼성전자 서초사옥 다목적홀 5층에서 진행되는 2013 S'데이 멤버십 블루 강연회 "Challenge BLUE, 박찬호&이동우의 삶과 도전" 멤버십 블루 고객 480명을 초청한다.강연회는 삼성전자 멤버십 블루 회원들을 위해 마련된 고객 혜택 행사로 한국인 최초의 메이저리거 박찬호와 시각장애 개그맨 이동우를 초청, 그들의 삶 속에서 펼쳐진 다양한 도전기를 들을 수 있도록 마련했다."""
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 2)

        text = """삼성전자가 11월 13일 삼성전자 서초사옥 다목적홀 5층에서 진행되는 2013 S"데이 멤버십 블루 강연회 "Challenge BLUE, 박찬호&이동우의 삶과 도전" 멤버십 블루 고객 480명을 초청한다.강연회는 삼성전자 멤버십 블루 회원들을 위해 마련된 고객 혜택 행사로 한국인 최초의 메이저리거 박찬호와 시각장애 개그맨 이동우를 초청, 그들의 삶 속에서 펼쳐진 다양한 도전기를 들을 수 있도록 마련했다."""
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 2)

        text = """삼성전자가 11월 13일 삼성전자 서초사옥 다목적홀 5층에서 진행되는 2013 S"데'이 멤버십 블루 강연회 "Challenge BLUE, 박찬호&이동우의 삶과 도전" 멤버십 블루 고객 480명을 초청한다.강연회는 삼성전자 멤버십 블루 회원들을 위해 마련된 고객 혜택 행사로 한국인 최초의 메이저리거 박찬호와 시각장애 개그맨 이동우를 초청, 그들의 삶 속에서 펼쳐진 다양한 도전기를 들을 수 있도록 마련했'다."""
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 2)

    def test_realignment(self):
        text = """'회사 동료 분들과 다녀왔는데 분위기도 좋고 음식도 맛있었어요 다만, 강남 토끼정이 강남 쉑쉑버거 골목길로 쭉 올라가야 하는데 다들 쉑쉑버거의 유혹에 넘어갈 뻔 했답니다 강남역 맛집 토끼정의 외부 모습."""
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 3)

    def test_prime(self):
        text = 'TV산업은 1926년 흑백 TV 개발, 1954년 RCA사가 Color TV(21") 양산/판매를 시작한 이래로 트리니트론 브라운관(1967년), 완전평면 브라운관(1996년) 개발 등 기술적인 발전을 거듭해 왔으나, 주요 국가 보급률이 90%를 넘어서면서 브라운관 TV사업의 성장은 정체되었습니다. 그러나 Flat Panel TV(LCD, PDP) 출시, 디지털 방송 확산(영/미 1998년~ )을 통해 TV 시장은 성장 모멘텀을 되찾았으며, FPTV는 화질, 디자인 등 제품 성능 향상과 지속적인 Set가격 하락을 통해 성장을 지속하며 기존 CRT 시장을 빠르게 대체하였습니다. 또한 2010년 입체감을 느낄 수 있는 3D TV가 출시되었고, 2011년부터 2012년에 걸쳐 인터넷 동영상 서비스 업체들의 부상과 스마트기기에 대한 사용자들의 관심 확대로 스마트 TV 시장이 태동하였습니다. 2013년에는 화질 및 해상도가 혁신적으로 높아진 UHD TV, 2014년에는 새로운 Form Factor인 Curved TV가 출시되었으며 2015년에는 퀀텀닷TV가 상용화되는 등 TV 시장은 끊임없이 진화하였습니다.전체 TV 수요는 2017년 기준 2억 1,510만대 수준으로 LCD TV 수요가 2억 1천만대로 99% 이상의 시장 점유를 이어 나갔으며, OLED 수요는 159만대로 성장하였으나 비중은 0.7%로 영향이 미미하였습니다. 2018년도 전체 TV 수요는 2억 2,100만대 이상을 기록하며 전년 대비 2.9% 성장하였습니다. 최근 TV시장은 고해상도 대형화면에 대한 Needs가 지속적으로 증가하여, UHD TV는 전년비 26% 증가한 99.6백만대로 시장 비중 45% 수준이 될 전망이며, 60"이상 대형시장은 약 19.7백만대를 초과하여 전년비 35% 성장, 75"이상 초대형 시장도 당사의 판매 드라이브로 전년비 76% 이상 성장이 전망되고 있습니다.'
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 7)

    def test_apostrophe(self):
        text = "그는 말했다. I'm good 괜찮아요. But He’s mind was broken."
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 3)

    def test_jyo(self):
        text = "아무래도 그땐 그랬었죠 많이 힘들었으니까요 근데 이제는 괜찮아요 친구들이 많아졌어요 그때만 힘들었던거죠 이젠 괜찮아요"
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 6)

    def test_EC_EF_cases(self):
        text = '국내에 판매하는 OEM 수입차의 판매량이 2017년까지 하락세를 보이다 지난해 반등했으며 수입차 대비 비중도 높아질 전망이다.'
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 1)

        text = '전과 8범 A씨는 지난 17일 전자발찌를 끊고 도주하다 붙잡혀 전자발찌 부착기간이 2020년 8월14일까지 늘었다.'
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 1)

        text = '국내에 판매하는 OEM 수입차의 판매량은 내년 보다 높아질 전망이다.'
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 1)

        text = "개그맨 김병만 씨가 아르바이트를 하다 목숨을 잃을 뻔한 사연을 TV조선 '별별톡쇼'에서 전했다."
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 1)

    def test_quotes(self):
        text = "연비테스트를 진행하면서 들었던 의문점인 ‘트립 컴퓨터 정보'에 대한 신뢰도 문제였다. 3대의 차량 모두 연료를 더 이상 들어가지 않을 때 까지 가득 주유한 뒤 193km를 이동했다."
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 2)

        text = '우리 팀 촬영 PD는 “지금까지 탔던 차 중에 가장 편했다"라고 말했다. 이런 쉐슬람 같은! 아니다.'
        splitted = kss.split_sentences(text)
        self.assertEqual(len(splitted), 2)

    def test_from_uoneway(self):
        cases = [
            '3일 한국자동차산업협회와 한국수입자동차협회에 따르면 한국지엠(GM)과 르노삼성 등 국내 완성차업체가 모회사의 해외 생산 차량을 수입해 국내에 판매하는 OEM 수입차의 판매량이 2017년까지 하락세를 보이다 지난해 반등했으며 수입차 대비 비중도 높아질 전망이다.',
            '경기도 특별사법경찰단은 소방공사 기간에 해외여행 중이던 상주 감리원이 현장에서 업무 한 것처럼 감리일지를 거짓으로 작성하는 불법행위를 한 감리업체 9곳을 적발했으며, 이들이 없는 틈에  공사 현장에서는 주요 소방공사가 그대로 시행됐다.',
            '2019광주세계수영선수권대회 기간 중 조선대학교에서는 수영대회의 ‘백미’인 하이다이빙 경기가 치러지며 조선대 본관 건물과 무등산을 배경으로 27m 높은 곳에서 뛰어내리는 아찔한 광경을 순간 포착하는 등 전 세계에 광주를 알릴 수 있는 절호의 기회가 될 것으로 보이고 하이다이빙은 단순히 경기를 넘어서 역동적이고 예술적인 모습이 포착되는 종목이어서 관객들의 시선과 탄성을 자아낼 것으로 보인다.',
            '전과 8범 A씨는 아동청소년 강간미수 혐의로 징역1년 3월형을 살고, 5년간 전자발찌 부착 명령상태에서 지난 17일 전자발찌를 끊고 도주하다 광주 북부경찰서가 검거하여 부착기간이 2020년 8월14일까지 늘었다.',
            '노르웨이 프리미엄 유아용품 전문 기업 스토케에서 부모가 서서 아이들을 목욕시킬 수 있는 신제품인 플렉시바스 스탠드를 출시함으로써 아이와의 목욕을 낯설어하던 육아대디, 배쓰 파파들에게 보다 즐거운 목욕 시간을 가질 수 있을 것으로 기대한다.',
            '이만희 자유한국당 의원이 4일 "청와대 회의에서 대통령의 국회 탓, 야당 탓이 연일 이어지고 있다 \'며 대통령의 정쟁 몰두식 인식전환을 촉구하며 470조의 슈퍼 예산을 편성해놓고도 1.5%도 안 되는 재난 추경을 내세우며 총선용, 현금살포용인 추경이 통과되지 않아 큰일이 날 것처럼 말하고, 6조 7천억 원의 추경이 없어 정책적 대응이 안되는 수준이라면 정부가 실력이 없는 것이다.',
            '해상교량의 점검에 안전성과 효율성을 높일 첨단장비가 투입돼 인력으로 고소작업에 의존하던 기존 방식에서 벗어나 보다 안전하고 효율적인 교량 점검을 수행할 수 있을 것으로 기대하고 있다.',
            '창원시는 벗꽃 개화가 예년에 비해 빨라진다는 예보에 군항제 공식 일정이 시작되기 전인 25일부터 주요 벚꽃명소를 부분 운영에 들어간다고 밝히고 31일 전야제 개막으로 화려한 꽃망울을 터트린다고 전했다.',
            "경기도는 지난 5일 경기창조경제혁신센터에서 국내외청년 200여 명이 참석한 '평화대담 토크쇼 비정상회담'을 개최했으며 이 날 청년들은 남북 정상회담과 북미 정상회담, 한반도 평화 실현의 방해요인 등에 대해 이야기하며 '한반도 평화'의 중요성을 강조했다.",
            "태안군이 친절한 민원서비스 제공을 위해 매주 월요일 아침 업무 시작 10분 전 직원들의 친절마인드 향상과 친절의 생활화를 도모하는 '미소 친절 방송'을 진행하며, 활기찬 직장 분위기를 위해 가요, 팝송 등의 음악도 함께 방송한다고 밝혔다.",
            '드라마 ‘은주의 방’ 11화에서는 류혜영이 김재영과의 갑작스러운 키스 후 혼란스러워하는 모습을 보이다 끝내 김재영의 마음을 거절하는 류혜영의 모습이 전파되었다.',
            '인천시 남동구노인복지관은 사할린에 있는 동포들과의 교류가 더욱 이루어지는것을 바라며 사할린을 방문해 동포들을 격려하고 상호 협력 논의와 역사와 문화·복지 서비스를 지원하고자 노력하겠다 "라고 약속했다.',
            '충주 중원 문화재단이 지난 8일 기존 이사들에게 카톡 메시지를 통해 11일까지 등기 동의서를 요구하는 등  신임 이사에 대한 서류 추인을 무리하게 강행하다 기존 이사들의 항의로 결국 무산됐으며 특히 신임 이사들의 법적 효력이 없어서 이사회를 개최하지 못하는 등 재단 운영이 비정상적으로 치달을 것으로 예상된다.',
            '전남도해양수산과학원은 섬진강에서 어린다 슬기 40만마리를 방류하는 등의 노력을 통해 하천생태계의 보전과 자원회복을 도모했다.',
            "'2019광주세계수영선수권대회'에서 수영대회 6개 종목 중 하이다이빙이 전체 입장권 판매율의 96%를 차지하며 최고 인기 종목으로 나타났다.",
            '광주시 동구가 ‘2019광주세계수영선수권대회’ 하이다이빙 경기 성공을 응원하고자 기업·기관·단체·개인 등이입장권 2천여 장을 구매해 관람석을 메울 예정이다.',
            "17일 광주광역시가 지난해 8월부터 아트도시 광주정책 추진, 광주 관문디자인 개선 등 다양한 사업을 수행해 온 가운데 지난 4일 '광주다운 도시공간 조성계획 용역' 착수보고회를 개최하고 '광주다운 도시만들기'를 본격 추진한다 밝혔다.",
            '광산구는 송정공원역과 신창동 행정복지센터에 스마트 도서관을 설치해, 시민에게 보다 편리한 도서 대여 서비스를 제공한다.',
            '부산 사상경찰서에 따르면 더불어민주당 권경협 의원이 지난 16일 밤 10시40분 사상구청 인근 도로에서 음주운전을 하다 경찰의 음주측정 요구에 불응하고 약 2㎞를 달아나다 경찰에 붙잡혀 불구속 입건됐다고 밝혔다.',
            '충남도는 도내 10개 산업단지가  충남국가혁신클러스터로 지정됨에 따라 \'수소전기차와 수소기반 산업 클러스터\'로 육성하여 수소경제 사회를 선도하겠다 "고 말했다.',
            "도심에서 사라져가는 것들을 기억하는 빛과 그림자 주제로 산수미술관(관장 장민한)이 노여운 작가를 초대해 오는 21일까지 전시회를 열고, 기억하다 :산수-사소한 풍경의 익숙한 침묵'을 주제로 열리는 전시에서 작가는 산수동과 주변 두암동, 지산동의 소소한 풍경을 담아낸 신작들을 선보이고 있다",
            "신한대학교는 일본군 위안부의 지워버리고 싶은 과거이지만 같은 역사가 되풀이되지 않도록 기억하기 위해 '평화의 소녀상'을 의정부캠퍼스 정문 앞에 건립한다 밝히고, 소녀상 건립과 함께 한민족평화통일연구원장의 초청특강까지 진행할 계획이라 밝혔다.",
            '서울시는 9·19 평양체공동선언 1주년을 기념해 강화군·옹진군·서울시·김포시·파주시·연천군·철원군·화천군·양구군·인제군·고성군 등과 국내 평화관광 활성화를 위한 상생협력 업무협약을 체결했으며, 지자체간 교류 협력 강화, 평화 관광 공동 프로그램 개발, 홍보 마케팅 활성화 등을 주요 내용으로 하고 있다.',
            '대전지방경찰청은 작년에 도로교통법 개정이후 대전지역은 4건의 자전거 음주운전 단속이 이루어지는 등 개정법이 유명무실하다는 지적이 나오는 가운데 경찰은 자전거는 주요 지점 단속이 어려워 주로 신고나 사고 발생 시 단속이 이뤄지고 있다고 밝혔다.',
            '보성군 벌교읍 산불진화헬기 추락 사고가 헬기 매뉴얼 규정보다 1m이상 긴 물주머니를 사용하다 꼬리 회전날개와 물주머니가 충돌하며 조종 불능 상태를 맞은 것이 원인이 된 것으로 밝혀졌다.',
            '농협유통이 18개 납품업자와 제주옥돔세트 등 냉동수산품 직매입거래를 하면서 1억2천여만원 상당의 총 4천329건을 상품에 하자가 있다 거나, 명절 등 특정기간에 집중 판매되는 상품이라는 등의 이유로 정당한 사유없이 반품하는 이른바 갑질 행위를 일삼아 공정거래위원회로부터 시정명령과 함께 4억5천600만원의 과징금 및 과태료 150만원을 부과받았다.',
            "2014년 11월 '캔디 젤리 러브'로 데뷔한 후 청순한 이미지로 남성 팬들의 마음을 사로잡은 러블리즈는, 1년 전 아시아투어를 하고 싶다 던 소망대로 오는 3월 싱가포르를 거쳐 홍콩, 대만까지 아시아 투어에 나선다.",
            '국토교통부는 저소득·다자녀·신혼부부에 대한 주거지원을 강화하기 위해 입주자 선정 가점항목 및 배점을 개편해 주거지원이 보다 절실한 가구가 유리하도록 개정안을 마련해 이달 30일까지 행정예고 한다고 9일 밝혔다.',
            "21대 선거를 앞두고 자신의 이익을 좇아 노선과 계파에 따라 흩어졌다 다시 뭉치는 '이합집산'은 한국 정치의 특징으로 보이고 있다.",
            "제2회 전라남도 평생학습박람회가 순천만생태문화교육원에서 '평생학습, 전남을 잇다! 사람을 잇다! 를 주제로 열리며 평생학습을 통한 소통과 축제의 장으로 치러진다.",
            '지난 6일 인천국제공항 고속도로에서 발생한 교통사고의 사망자가 20대 여성의 탤런트였던 것으로 알려진 가운데 이 사건에 대해 네티즌들은 차량 블랙박스를 확인해봐야 한다 거나 사고의 책임이 사망자에게 있다는 등의 반응을 보이고 있다.',
            '윤창호법 시행 후 첫 설 명절을 맞아 대전경찰청은 오는 2월 6일까지 사고다발지역에 가용인력을 최대한 많이 배치하여 음주운전 집중 단속을 벌이기로 했다.',
            '경찰은 최근 전남도교육청의 학교물품 구입 비리 의혹에 대한 압수수색 중 전·현직 공무원들이 업자로부터 해외 골프 접대를 받았다 의심할 만한 정황을 포착하면서, 수사 결과에 따른 파장이 예상된다.',
            "충주의 사이다 제조 회사인 '댄싱사이더 컴퍼니'가 농림축산식품부의 '2019년 농업과 기업 간 연계강화사업' 대상으로 선택됐는데, 이 회사의 애플사이더는 생사과즙을 발효시켜 사과 본연의 맛을 담은 사이다 제품으로, 알코올 도수가 맥주와 비슷해 부담 없이 마실 수 있다.",
            '인천시 동구는 가을을 맞아 지역 내 공원, 가로녹지대 등 주민들이 자주 왕래하는 주요 공간의 화단에 금어초, 천일홍, 국화 등 가을 꽃을 심어서 주민들에게 쾌적하고 아름다운 공간을 제공할 것이다.',
            '종이원료를 공급하는 3개 업체가 각자 거래하고 있는 제지업체들에 대해 주요 품목의 가격을 5-10% 인상하면서 가격을 담합하다 과징금과 검찰 수사를 받게 되었다',
            '한국 콜롬비아전 MBC 축구 중계를 한 BJ감스트는 인터넷방송 출신을 왜 공중파에 기용하는지 이해가 안 간다, 일반사람들이 생각할수 있는 그런 말들을 콕 집어서 말한 거 같아 캐사이다라는 엇갈린 반응에 대해 사과했다.',
            '가맹사업진흥법 개정으로 가맹사업 기본계획 및 실행계획을 추진하는 실태조사 범위가 산업재산권에서 지적재산권까지 넓어짐에 따라 가맹업계에서 종종 이뤄졌던 상품 카피가 더욱 면밀히 관리되는 등 지적재산권이 보다 강화될 전망이다.',
            '대검찰청은 25일부터 새로운 ‘교통범죄 사건처리기준’을 마련해 음주운전을 하다 사람을 치어 교통사고를 낼 경우 음주 수치에 따라 최대 무기징역까지 구형하는 등 구형량을 높이기로 밝혔다.',
            '지난달 취업자가 26만여 명 증가하며 13개월 만에 가장 큰 폭으로 늘어났지만, 제조업 같은 주요 산업에선 오히려 일자리가 줄어든 만큼, 외형적 지표에 만족하기 앞서 양질의 일자리 창출이 절실하다는 점을 유념해야 한다.',
            'LG는 응급의료 전용 헬기 도입, 국가 응급진료 정보망 구축과 재난응급의료 상황실 운영 등 응급의료 발전을 위해 헌신하다 순직한 고 윤한덕 국립중앙의료원 중앙응급의료센터장에게 의인상을 수여하고 유가족에게 위로금을 전달키로 했다.',
            '포스코가 사회공헌 분야에서 기업시민 봉사상을 신설해 여러가지 평가요 소를 고려해 매년 외부 단체및 사내를 대상으로 포상하기로 발표했다.',
            "지난 3월 타계한 프랑스 누벨바그를 이끈 여성감독, '누벨바그의 대모' 고 아녜스 바르다 회고전 9편의 영화가 오는 5~6일 광주시 동구 광주극장에서 개최된다.",
            'MBC 새 월화드라마 ‘아이템’의 제작발표회에서 배우 주지훈이 "“감독님이 적토마 같다고 해서 이게 욕인지, 칭찬인지 한참 헷갈렸다. "며 소감을 전했다.',
            '광주지법은 지난 3월 음주운전을 하다 도로에 서 있던 A(60·여)씨를 친 뒤 조치를 취하지 않고 달아나 결국 사망에 이르게 한 정모(47·남)씨에게 특정범죄가중처벌등에관한법률위반(도주치사)등 혐의로 죄질이 나쁘다고 고려해징역 7년을 선고했다고 10일 밝혔다.',
            '경기도 특별사법경찰단은 개발제한구역 수사권을 얻은 이후 지난 7월 15일부터 26일까지 경기북부 개발제한구역 내 동식물 관련 시설이나 농업용 창고로 허가를 받은 53곳을 수사한 결과, 작업장 또는 주택 등으로 불법 용도 변경해 사용하다 적발된 17개 시설의 업주 17명을 형사입건했다고 5일 밝혔다.',
            '상사화는 수선화과의 여러해 살이 식물로 꽃과 잎이 서로 달리 피고 지는 모습이 인간세계에서 서로 떨어져 사모하는 정인들과 같다 하여 붙여진 이름인데, 이 꽃의 이름은 흔하지 않게 경운 스님이 인도의 공주를 잊지 못하여 병에 걸린 애절한 사랑 이야기를 담고 있다.',
            '국내 상반기 일본차 수입액은 26.2%나 뛰어 역대 최대를 기록했으나 국산차는 일본수출이 없다 시피 했다.',
            '옥천군에 따르면 올해를 관광옥천 도약의 원년으로 선포하고 지역관광지 알리기를 추진하며 그 일환으로 주요 관광안내소와 협력체제를 구축하고 발로 뛰는 관광마케팅을 시작했다.',
            '부산광역시 해운대 경찰서는 온라인 게임에서 사기 행각을 벌이다 지명수배된 20대 A 씨를 편의점에서 상습적인 절도 혐의로 구속했다고 21일 밝혔다.',
            '레드벨벳 멤버 웬디가 25일 SBS 가요 대전 리허설 중 큰 부상을 입은 것에 대해 레드벨벳 갤러리는 SBS의 안전불감증이 여전히 심하다며 SBS가 웬디에게 진심으로 사과하고 이번 사고의 진상 규명이 빠르게 이루어지지 않으면 법적 대응으로 이어질 것이라고 밝혔다.',
            '올해 가평군 공식 블로그 방문자수가 전년대비 318%증가하면서 가평관광 활성화에 큰 축이 되어 온라인 홍보창구로 자리매김을 하고있으며, 사람들이 신뢰할 정보를 바탕으로 올바른 정보를 얻어갈 수 있도록 주요 현장들을 직접 방문한 소셜미디어 기자단의 노력으로 지역경제에 활력을 불어넣고 있다.',
            '광주시는 주요 사업을 추진함에 있어서 시민, 현장, 의회와 소통해야 한다.',
            '부산사하경찰서는 2일 길가에 세워둔 차량을 몰다 사고를 낸 러시아인 선원 P씨를 불구속 입건했고, 앞으로 에이전시를 통하여 P씨를 소환해 정확한 사고 경위를 조사할 예정이다.',
            '한국소비자원이 고령소비자의 합리적인 선택을 지원하기 위해 이동통신 3사의 실버요금제를 분석하여 나온 결과로 일반 저가요금제와의 차이가 미미하거나 오히려 데이터 제공량이 적은 것으로 나타났다.',
            "JYP엔터테인먼트 신인 걸그룹 ITZY(있지)가 첫 디지털 싱글 ‘IT’z Different’의 타이틀곡 ‘달라달라'를 발표하고 정식 데뷔한지 10일 만에 음악 방송 1위에 오르면서 가요 계에 등장하자마자 관심을 모으고 있다.",
            '지난달 27~28일, 광주세계수영선수권대회조직위원회가 파워 블로거와 수영 전문인 등 20여 명을 초청해 국제방송센터와 남부대시립국제수영장, 수구경기장, 조선대하이다이빙 경기장 등 주요 시설을 방문하는 팸투어를 실시했다.',
            '한국민화디자인센터와 다겸아트컴퍼니가 기획한 ‘한국을 담은 민화 특별전, 한국을 담은 한복전’이 오는 28일까지 하이다이빙 종목이 열리는 조선대 중앙도서관과 국제관에서 열리는데, 23일 수영대회 응원차 광주를 찾은 김정숙 여사가 들르기도 했던 민화전은 서울 가회민화박물관(관장 윤열수) 소장품을 만날 수 있는 기회이며, 민화전에는 화조도, 장생도, 모란도, 책가도 등 19세기 작품 116점이 전시되며 수영대회를 맞아 물 속의 물고기들이 평화롭고 자유롭게 노니는 모습을 표현한 ‘어해도’를 선보인다.',
            '전남대 여수캠퍼스가 주최하는 외국인 유학생 자율방범대에 참여한 외국인 유학생들은 앞으로 범죄예방차원에서 외국인유학생 밀집지역의 집중순찰 및 범죄피해에 대한 신고요원 역할을 할 것이다.',
            '르노삼성자동차의 도미닉 시뇨라 사장이 부산상공회의소 허용도 회장을 만나 투 트랙 전략으로 신뢰를 되찾겠다 밝혔으며 임단협 진행 상황을 공유하고 지역상공계가 해야 할 역할 강화 방안도 논의했다.',
            '충북도는 4차 산업혁명 시대에 제조분야의 경쟁력 확보를 위해 기업 부담금을 일부 지원하는 등 스마트공장 보급 확대에 힘쓸 계획이라고 13일 밝혔으며 또한 스마트공장 수요. 공급기업 간 매칭데이, 스마트 공장 설명회도 주최할 예정이다.',
            '매년 여름 잠실 종합운동장과 같은 트렌디한 장소에서, 세계 1등 사이다 브랜드인 스프라이트가 지난 20일 다이브 인 스프라이트 존, 워터밤을 운영해 관객들에게 상쾌한 경험을 선사했다.',
            '더불어민주당 지방혁신균형발전추진단과 대통령직속 국가균형발전위원회는 17일 신년간담회를 개최하고 2019년 균형발전을 위한 정책과 주요 현안을 논의했다.',
            '지난 31일 국회에서 이용섭 광주시장이 민주당과 예산정책협의회를 가지고 지역 국회의원들과 예산 간담회를 실시했으며, 김영록 전남지사가 전혜숙 행정안전위원장에게 지역 주요 현안을 설명하고 협조를 구하는 등 광주시와 전남도가 내년도 주요 핵심 현안사업에 대한 국비 확보를 위한 노력을 펼쳤다.',
            '작년 12월 31일 포천시 A업체에서 지게차 위에 올라가 천정에 묶인 커튼 휘장을 걷어내던 직원이 떨어져 사망한 사고가 발생했고, 이에 대해 재판부는 보호구도 지급하지 않고 중장비 등을 다른 용도로 사용하다 사고 발생에 대한 책임은 사업주에게 있다는 판결을 내렸다.',
            '2017년 9월부터 2월까지 경남 산청군 단성면 연수원 및 야구장을 관리한 직원이 경성대 학내 게시판에 총장을 비판하는 글을 올렸다가 산청에 발령을 받았다며 국가인권위원회에 진정을 접수한 것으로 알려졌다.',
            '완도군은 직장운동경기부 운영을 활성화시키고 선수들의 경기력 향상을 위해 완도 체육공원 내에 6억원의 사업비로 역도훈련장을 신축, 이달부터 운영에 들어가는데, 군에 입대하는 이양재와 전직을 위해 사직한 이상혁의 공백을 메우고 팀 전력을 보강하기 위해 신비(19), 최가연(23) 등 2명을 영입하며 "훌륭한 선수들이 보강된 만큼 선수들이 최고의 기량을 발휘할 수 있도록 각종 지원을 아끼지 않겠다고 말했다.',
            '여야 4당 원내대표는 공동 성명을 발표하면서 자유한국당을 향해 "당장 내일이라도 5당 원내대표 회동을 제안한다 \'고 밝혔다.',
            '3년만에 늘었다 던 여수시의 인구가 주거 여건의 불안정 등을 이유로 두 달만에 다시 감소하며 여수시는 인구 증가 정책의 근본 대책 마련이 급하다는 비판을 받고 있다.',
            "광주수영대회 조직위원회에 따르면 '2019광주세계수영선수권대회'가 종반으로 접어든 가운데 가장 큰 관심을 끌고 있는 하이다이빙과 수영대회의 꽃인 경영 등 인기 종목들이 일제히 시작되면서 대회 흥행몰이에 나선다.",
            '전라남도는 지난 21일 국회 본회의에서 최종 의결된 추경예산에 주요 현안 예산 24건, 921억원의 국고 예산을 확보한 것으로 집계됐다고 밝혔는데, 이 중 지역 주도형 청년일자리 사업 100억원, 희망근로 지원 19억원 등 전라남도의 청년 일자리 창출 및 고용위기 극복을 위한 현안 사업비가 대거 반영됐다.',
            "부산지법 형사10단독은 학교 근처에서 속칭 '키스방' 영업을 하다 적발된 전직 경찰에게 징역 2년의 실형을 선고했다.",
            '수성아트피아는 올해를 재도약 원년으로 삼아 명품공연장의 위상을 재확인하는 과정에서 가장 눈에 띄는 변화는 발레 중심 공연장으로서의 이미지 제고로 시민들에게는 존재감이 분명한 아트센터, 예술인에게는 성장의 발판이 될 수 있는 든든한 버팀목이 되겠다 "고 밝혔다.',
            '전남 영암 소산리 자연사이농원의 농업인 신순희 씨는 최근 늘어난 1인가구 소비 트렌드에 따라 기존 수박의 4분의 1크기로 미니수박으로 불리는 애플수박을 재배하며 기존에 청양고추를 재배하던 때 보다 2~3배 이상 수익이 늘었다고 말했다.',
            '지난 26일 인천공항 제2여객터미널 입국불허자 대기실에 대기 중이던 러시아인, 우즈베키스탄인, 카자흐스탄인 등 3명이 공항 화장실 환풍구로 밀입국을 시도하다 서측 안내카운터 인근 경비보안요원들에게 붙잡혔다.',
            "17일 방송된 TV조선 '인생다큐 마이웨이'에 출연한 트로트 가수 김혜연은 과거 뇌종양으로 슬픔에 잠겨 있다 기적적으로 병을 극복한 사연을 소개했다.",
            '노인 배식 도우미 자원봉사를 진행하다 인연이 된 오산세교로타리클럽과 신장동 지역사회보장협의체 그리고 오산시 신장동 행정복지센터는 관내 저소득층의 맞춤형 복지서비스 제공 및 주민 복지욕구에 보다 효과적인 대응을 위한 업무협약을 체결했다고 29일 밝히고 오는 8월 8일 관내 지역아동센터 아동들과 캐리비안베이 여름나기 행사를 시작으로 지역민들의 다양한 활동에 적극 협력하기로 했다.',
            "농촌지역 인구가 고령화하면서 농·어·임업 활동을 포기하거나 아예 업종을 바꾸는 전국적인 추세에 따라 '2018 농림어업조사' 결과에서 충남지역 농가는 12만 3000가구로 전년 12만 6000가구 대비 1.9% 줄었으며 어가, 임가도 일제히 감소한 것으로 나타났다.",
            '대전시가 천변도시 고속화도로 하이패스 설치와, 도시철도 1호선 스프링클러 설치 부분 등 시민 생활과 직결된 현안해결에 소극적인 태도를 보이다 수차례의 질타 후 하겠다는 반응을 보여 빈축을 사고 있다.',
            "중앙부처가 '제3차 항만 재개발기본계획' 용역을 추진하다 서천군이 금강하구 일원의 난개발 문제를 제기하면서 용역이 중단된 바 있는 군산시의 인공섬 금란도는 군산시에 많은 경제적 이익을 주고, 양지자체간 상생의 의미가 큰 사업이기에 서천시도 긍정적으로 바라봐야한다는 의견이 나오며 양 지역민들의 관심이 집중되고 있다.",
            '불후의 명곡-전설을 노래하다 에 출연한 손준호는 성악을 배우기 위해 중학생 때부터 김동규의 집에서 동고동락을 하였다고 밝히면서 놀라움과 훈훈한 분위기를 자아냈다.',
            '당진시가 올해 전국 최초로 근로자가 최소한의 인간다 운 삶을 보장하기 위해 기준 중위소득 50% 이하의 취약계층과 그와 세대를 같이하는 직계존비속에게 주거비와 교육비, 물가상승률 등을 종합적으로 고려해 최저임금보다 높은 수준의 소득을 보장해 주는 청년생활임금제 시행을 앞두고 있다.',
            '29일 한국무역협회 대구경북지역본부는 지난해 대구, 경북지역 기업 수출이 전년 대비 5.9% 감소하였고, 대구 수출은 자동차부품과 산업기계 덕분에 전년 대비 12.3% 증가해 사상 최고치를 찍었지만 경북은 세계 스마트폰 시장의 감소로 주요 수출 품목들이 부진한 모습을 보였다고 밝혔다.',
            '미중 무역전쟁 여파와 일본의 수출 규제 등 악재 속에서도 주요 신흥국 중에서도 한국 증시에 글로벌 자금이 가장 많이 유입된 것으로 나타났다.',
            '세월호 참사 5주기를 하루 앞둔 지난 15일 오후, 차명진 자유한국당 경기 부천 소사 당협위원장의 SNS 글이 논란이다. 한국당의 황교안 대표와 박근혜 전대통령이 세월호 사고 책임자로 고발당한 것에 대해 세월호 유가족을 원색적인 언어로 비난하였는데, 이와 관련해 논란이 커지자 차 위원장은 사과글을 남기고 SNS와 방송 활동 중단을 선언했다.',
            '15일 국무조정실 정부합동 부패예방감시단은 어업법인 운영실태 조사에서 수산보조금 위반 138건의 위반사례를 적발하고, 앞으로 분기별로 점검해 보조금을 보다 효과적으로 사용할 수 있도록 하겠다고 전했다.',
            "정부는 대학별로 입학정원 감축을 자율화 했으며 적정 정원 수준으로 입학생을 줄인 대학을 '일반재정지원대학'으로 선정하겠다 밝혔다.",
            '순천여고 정구부가 전국정구대회 여자 고등부 단체전 우승을하였고 개인단식에 출전한 4명 모두 4강진출해 각 우승 및 준우승 3위로 오르며 개인다식도 4자리 모두 쓸었으며 이러한 성적은 한국 정구 역사상 처음으로 진기록을 세운 순간이다',
            '퓨전·대중가요 ·전통음악 등 여러 장르의 공연을 즐길 수 있는 ‘삶·숨·쉼이 있는 흥겨운 문화마당’이 오는 21일 오전 11시 곡성군 죽곡 봉정분교 목공예&커피체험관에서 개최된다.',
            '중소기업중앙회가 24일 발표한 경영전략조사에 따르면 중소기업의 86%는 투자 및 신사업 계획이 없다 응답했으며 이는 경기전망에 대한 부정적 인식이 영향을 미친 것으로 나타났다.',
            "인천시교육과학연구원이 개최 한 학생대상 '2019 인천시 과학동아리 활동 발표대회'의 참가팀들은 대회 참가를 통해 팀원들과 협업하는 과정과 과학진로 역량을 기를 수 있는 기회가 되었다고 얘기했고, 관계자는 과학 관련 동아리 활동을 더욱 활성화 시킬 수 있도록 지속적인 노력을 하겠다 밝혔다.",
            '보건복지부의 국민건강 보험법 및 의료금여법 시행령 일부개정령안이 국무회의에서 의결되어 의료계의 반발을 샀던 추나요법을 환자 본인이 1만-3만 원만 부담하고 진료를 받을 수 있다.',
            '그리스의 한 TV쇼 출연진들이 방탄소년단과 엑소의 외모를 비하하는 발언을 하여 논란인 가운데 염색한 모습이 끔찍하다, 여자 같다 등 비하 발언의 수위가 상당히 심해 많은 팬들의 항의가 이어지자 출연진들은 그제서야 사과를 하였다.',
            "세종시는 정부세종청사 21개 정부부처 공무원을 대상으로 실시한 행정수도 관련 인식조사 결과에서 80%이상이 '국회 세종의사당' 설치가 필요하다고 밝히며 세종시장은 행정 비효율이 심각하고 해당 기관들의 설치가 시급하다 밝혔다.",
            "수성문화재단은 대구시민주간을 맞아 28일 오후 8시 수성아트피아 무학홀에서 현인의 노래 '비 내리는 고모령'을 비롯한 한국가요 명곡들과 수성구의 역사문화자원을 변사가 스토리텔링 방식으로 진행하는 변사극 '비 내리는 고모령'을 공연한다.",
            "최근 자신의 삶을 녹인 수필집을 낸 저자는 대전지방경찰청에서 30년 간 경찰로 근무하다 퇴임 후 칼럼과 글을 활발히 쓰고 제6회 '한국문학시대 문학대상'을 수상하기도 했다.",
            '영동군은 지난 2일부터 7일까지 군청 상황실에서 주요 현안사업의 중단 없는 추진과 군민들의 행복을 실천하기 위한 주요 군정에 대한 구체적 실천 전략들을 제시하며 2019 주요업무 추진계획 보고회를 가졌다.',
            "21일 한국토지주택공사(LH) 경기지역본부는 건설 현장 내 재해요 소에 선제적으로 대응하고 안전사고 발생 시 즉각 조치가 가능하도록 'LH 안전 휘슬 제도'를 시행한다고 밝히고 건설 현장 내 모든 근로자의 안전모에 부착이 가능한 형태로 지급한다고 했다.",
            '환경가전을 많이 사용하다 교원웰스 제품을 접하게 된 김 지점장은 물 속 미네랄 성분의 중요성에 눈을 뜨면서 교원웰스에서 일하게 되었고 동시에 지역 가수로도 활동하고 있다.',
            '2015년 ‘유심’ 신인상을 수상하며 작품활동을 시작한 광주 출신 박노식 시인이 ‘이 시대의 외톨이’라고 시인의 존재를 규정해 그의 웅숭깊은 언어를 대면하며 잠깐이나마 ‘모두가 외톨이’가 되는 고요 와 침잠의 시간을 독자들이 상상하게 되는 두 번째 시집 ‘시인은 외톨이처럼’을 펴냈다.',
            '23일 조선대학교에서 열린 여자 하이다이빙 최종전에서 호주의 이프랜드가 금메달을 차지해 여자 하이다이빙 최강자임을 다시 한번 입증했다.',
            '여수 은파교회 고만호 목사가 3·1운동 설교에서 5·18민주화운동을 ‘끔찍한 폭력’이라고 규정한 사실이 알려지면서 공분을 사  "3·1운동이 비폭력이었음을 강조하기 위한 것이었다”며 어떤 왜곡이나 폄훼할 의도는 추호도 없었다 "고 사과했다.',
            '28일 한국철도공단은 동암역 지하연결통로 상가에 있던 28개 점포 철거 완료 후 새 민간사업자를 찾고 있지만 그 지역에서 10년 가까이 생업을 유지하다 철거 당한 상인들의 불만이 자자하다.',
            '지난달 27일 송악농협 대공연장에서 당진시 이통장 워크숍과 당진시지회장의 이취임식이 열려 당진지역 273의 이통장을 대상으로 인권교육과 주요 시정 및 지역 현안에 대해 설명하는 시간을 가졌다.',
            '23일 전남도에 따르면 살처분보상금 감액과 과태료 상향 등을 주요 내용으로 하는 가축전염병 예방법 시행령이 개정돼 7월 1일부터 구제역 백신접종을 하지 않은 농가는 구제역 발생 시 보상금을 한 푼도 받지 못하는 등 강력한 불이익을 받는다.',
            '자유한국당 주호영의원은 30일 국회에서 열린 한국당 비상대책위원장-중진의원 연석회의에서 황교안 전 국무총리와 오세훈 전 서울시장의 출마자격 부여에 대해  "당헌·당규를 따르지 않고 입당했다고 다 피선거권을 준다면 앞으로 기회주의자만 나올 것"이라고 비판,"힘으로 밀어붙이면 기록하고 책임지도록 해야 한다 \'고 지적했다.',
            '21일 대구 중구청은 91명의 사상자가 발생한 중구 포정동 대보사우나 화재 사고의 피해 복구에 노력하고 있으며 이날 한국전력이 대보상가. 아파트 전력 복구 작업에 나서 완료에는 최대 2주가 걸릴 것으로 예상된다고 전했다.',
            '2019광주세계수영선수권대회 하이다이빙 종목이 지난 22일부터 24일까지 진행됐으며, 팬들에게 큰 볼거리를 제공해 흥행몰이에 성공했다.',
            '5·18 당시 현장에서 투쟁하다 한쪽 눈을 잃은 이지현(이세상)씨의 자전적 이야기 ‘애꾸눈 광대’가  8일부터 11일까지 오후 7시 30분 광주 동구 궁동예술극장에서 막을 올린다.',
            '이철우 경북도지사는 주요 현안사업에 대한 정부예산안 반영을 위해 19일 안일환 예산실장과 중앙정부에 방문해 경북도 현안사업을 설명하고 주요 현안사업에 대한 전폭적인 지원을 부탁했다.',
            "국내 최초 MCN 전문기업 트레져헌터는 5일, 3세대 모델인 '전문가 채널'을 런칭하며 김호인 변호사가 MCN 자문 변호사로 활약하다 법률 이슈를 쉽게 설명하는 크리에이터 활동을 시작했으며 김병지 전 축구선수는 '꽁병지TV'를 통해 운동 콘텐츠를 만들어 성장 가능성을 보여 주고 있다.",
            '사이다 특가 좌석의 폭발적 반응에 따라 에어서울에서 사이다 특가 좌석을 27일, 28일 오전 10시 추가로 오픈해 판매한다.',
            '이인영 원내대표는 국회 교섭단체 연설에서 매달 1일 자동으로 국회를 열어 빈손 국회를 원천 차단해야 한다 말하며 1년 365일 상시국회 체제를 위해 국회법을 개정하자고 주장하고 국회의원에 대한 국민소환제를 도입할 것을 제안했다.',
            '이용석 광주시장은 정책간담회에서 경제 산업 전반의 패러다임이 급격히 변화하는 무한 경쟁 시대에 지역경제의 근간인 중소기업들의 지속 성장을 위한 경쟁력 강화가 매우 중요하다 ”며 “내년에도 시정 제1목표인 일자리 창출을 위해 창업 활성화와 지속성장 기반 구축, 유망 중소기업 육성, 스마트 제조혁신을 통한 중소기업 경쟁력 강화에 매진해 나가겠다 "고 강조했다.',
            '최근 30도를 웃도는 고온다습한 날씨 속에서 나주시가 오는 7일까지 중점 방제기간을 정하고, 장성군도 지난 4일부터 7일간 ‘돌발해충 공동방제의 날’로 정하는 등 전남 자치단체들이 ‘돌발해충’ 피해 및 확산 방지를 위한 선제적 대응에 나서고 있다.',
            '대전지방경찰청은 지난달 10일 대전 중구 대흥동에서 무면허로 머스탱 차량을 운전하다 사망사고를 낸 운전자 전모(17) 군을 교통사고처리특례법(치사)위반 혐의로 구속했다고 6일 밝혔다.',
            '지난 10일 해남군은 15억원을 투입해 군청사 신축 공사와 연계한 해남읍성 복원과 주변 정비사업을 착공하여 해남읍성을 지역의 역사문화 랜드마크크로 복원한다 밝혔다.',
            '2019광주세계수영선수권대회조직위원회는 하이다이빙 경기장을 찾아 온 세계 각국의 선수·임원과 관람객들을 위해 한국인의 생활상과 풍습을 한 눈에 볼 수 있도록 ‘민화 특별전’을 개최하여 우리 문화의 우수성을 세계에 널리 알리는 절호의 기회로 한국전통 예술이 세계인들에게 더욱 친숙하고 사랑받는 계기가 될 것이라고 밝혔다.',
            '10여 년 전 미성년자를 성폭행한 뒤 흔적을 지운 A씨는 지난 2월 만취한 여성 승객과의 성추행 문제로 실랑이를 벌이다 경찰서를 찾았고, 경찰은 DNA 감식 과정에서 검출된 결과와 A씨의 몸에 있는 문신 모양에 대한 성폭행 피해자의 진술을 통해 A씨의 자백을 받아냈다.',
            '22일 광주시와 전남도. 기상청 등에 따르면 이달 초 제13호 태풍 ‘링링’의 피해 복구가 한창인 상황에서 또다시 제17호 태풍 ‘타파’가 광주·전남에 많은 비를 뿌려 직격탄을 맞으면서 이에 농민들이 망연자실 해하고 있다.',
            "한국무역협회 인천지역본부는 '일본 수출규제 대응 및 통상전략 2020 설명회’를 개최하여, 유관기관과 사전 대응 및 피해 기업에 총력을 기울이고 있다 말했고, 일본 수출규제 관련 피해를 최소화하기 위해 '피해기업 접수 센터'를 운영 중이다.",
            '내년부터 서울 초등학교 3학년생과 중학교 1학년생은 3월 중 표준화된 도구로 기초학력진단평가를 받아야 하며, 초등학교 3학년행은 읽기.쓰기.셈하기능력, 중학교 1학년생은 해당 능력에 국어. 영어. 수학 교과학습능력을 평가받으며 진단결과는 평소 학습태도 등에 대한 분석과 함께 보호자에게 통지된다.',
            '2019학년도 대입 수능 당일 새벽 교육청에 배송된 시험지를 보관 및 감독하던 장학관이 사우나에 갔다 온 사실이 함께 배치된 교육부 파견 중앙협력관의 제보로 드러나 교육 당국이 감사에 들어가 해당 행위가 근무 태만에 해당하는 것으로 보고 징계의결 요구 수위를 검토 중이다.',
            '스포츠 브랜드 노이타는 건강하고 밝은 이미지가 동사 제품과 잘 맞으며 브랜드 인지도 향상과 이미지 제고에 크게 이바지한 가수 추화정과 전속 모델 계약을 1년 더 연장했다고 전했으며  그녀는 브랜드 홍보에 최선을 다하겠다 "고 소감을 밝혔다.',
            "대구시는 올해 1월15일부터 2월14일까지 공동주택 공동체 활성화사업을 공모해 37개 사업을 신청받아, 심사를 거쳐 16개 사업, 총 사업비 9천500여 만원을 지원키로 결정했으며 선정된 사업중 동구 대구혁신도시서한이다음의 '다정한 이웃, 사람중심 행복한 대구혁신도시 서한이 다음'이 가장 높은 점수를 받은바 있다.",
            '이번 광주세계수영대회에서  하이다이빙 경기를 총괄하는 이종희 담당자는 현재까지 시설이나 선수가 전혀 없는 하이다이빙 종목을 모두가 사랑하고 즐길 수 있는 스포츠로 성장시키고 싶다고 포부를 밝혔다.',
            '출퇴근 시간대 이용자들이 일시에 몰려 제때에 버스를 타지 못하는 병목정류소에 점핑버스 또는 3-Door 출퇴근 전용버스가 추가 투입되고, 또한 노폭이 좁고 이용 수요가 적은 곳에는 준중형버스를 운영하며, 노선 신설이 필요한 경우 입찰제를 도입하는데, 먼저 시민들에게 보다 편리하고 개선된 대중교통 서비스를 제공하려고 많은 사람들의 의견을 반영한다고 말하였다.',
            '오는 3월부터 한방추나요법에 건강보험이 적용되면서 환자의 본인부담금이 감소하는 만큼 추나 이용 환자의 증가가 예상됨에 따라 대전지역 한의학계의 기대가 높아지고 있다.',
            '인천 지역 주민들이 인천 송도국제도시를 기점으로 주요 지역 80.1km 구간을 잇는  GTX-B노선 사업의 예비타당성 조사 결과 발표가 초읽기에 들어가자 교통환경 개선의 물꼬가 트일 것이라는 기대감에 들떠있다.',
            '이번 광주수영세계선수권대회에서 최고 관심종목인 하이다이빙 경기가 36명의 선수가 출전한 가운데 22일부터 24일까지 사흘간 조선대학교 경기장에서 진행된다.',
            '여론조사 전문기관 리얼미터가 전국 19세 이상 유권자 2천18명을 대상으로 실시한 문재인 대통령 국정수행 지지도(긍정평가)결과 지난주보다 1.7%포인트 상승한 49.1%으로  7주 연속 40%대 후반을 유지하다 50%에 육박했다.',
            '부산경영자총협회가 주요 기업 131개사를 대상으로 실시한 설 연휴 및 상여금 실태 조사 결과, 부산지역 기업 중 설 상여금 제공 예정 기업이 작년보다 소폭 감소한  68.5%인 것으로 조사됐다.',
            '해원초등학교에서 15m 떨어진 해운대구의 우3동 아파트 밀집지에 65층짜리 주상복합 건립을 위한 지구단위변경신청이 시도되자 주민들은 해원초등학교의 학습권이 침해되는 데다 주변 아파트의 일조권 등의 문제가 심각해질 것이고 구청장이 교육청에 책임을 전가한 것이라며 비판했다.',
            '청소년 범죄가 매년 지속되는 가운데 경찰은 솜방망이처벌이 주요원인이라고 이야기하면서 보호관찰처분 수위를 조금 더 강하게 내리는 것이 청소년 범죄 예방에 도움이 될 것이라고 말했다.',
            "인천시 서구가 14일 경인아라뱃길 시천나루에서 음식점과 숙박시설의 정보를 제공하는 무인정보안내시스템인 '맛집 정보안내시스템(키오스크)' 구축 제막식과 함께 시연회를 열고 서구를 방문하는 나들이객의 음식점과 숙박시설 이용을 유도하겠다 밝혔다.",
            '대한빙상경기연맹 관리위원회는 지난달 24일 충북 진천선수촌에서 여자 선수 숙소동에 들어갔다 적발된 쇼트트랙 대표팀의 김건우에 대해 출전정지 1개월과 그의 출입을 도운 김예진에겐 견책 처분을 내리고  퇴촌과 동시에 각각 재입촌 금지 3개월, 1개월의 징계도 내렸다.',
            '부산 사하경찰서는 지난 16일 오후 7시 20분 사하구 괴정사거리에서 신호등 정지 신호를 피하려고 진로를 변경하며 주행하다 6중 추돌사고를 일으킨 김모(48) 씨를 교통사고처리 특례법 위반 혐의로 불구속 입건했다.',
            '지난 15일 취임한 김태봉 대덕대 총장은, 이날 기자 간담회에서 2013년부터 시작된 교직원 임금 문제는 상당한 재정 투입이 요구되지만 여건이 허락되는 범위 내에서 우선 순위로 해결해 나갈 것이며, 4차산업혁명시대에 걸맞는 중장기 대학발전계획 역시 재수립해 나가겠다 다고 밝혔다.',
            "지난 2일 KBS 2TV ‘살림하는 남자들 시즌2'에서 최민환과 율희가 아들 재율을 데리고 계획에 없던 쇼핑을 하다 지쳐버려 넉다운되는 모습을 방영했다.",
            "대전에서 무면허 운전을 하다 사망사고를 일으킨 10대 운전자에 대한 첫 공판이 17일 열리며, '대전 머스탱 사고'로 알려진 이 사건은 무면허로 머스탱 차량을 운전하던 A(17)군이 지난 2월 중구 대흥동에서 연인 관계에 있던 B씨와 C씨를 덮쳐 1명이 숨지고 다른 1명은 중상을 입은 사고로 이번 공판은 대전집버 형사6단독(부장판사 믄홍주)으로 진행될 예정이다.",
            '제15회 영 호남 시 도지사 협력회의에서는 주요 현안들인 영 호남 관광교류활성화, SOC 분야 공동 협력, 그리고 세계수영선수권대회 홍보 협조를 위해 지자체 간의 상호 협력을 도모하는 시간을 가질 것으로 보여 이들의 결과물에 많은 관심이 쏠려 있다.',
            '태안군이 10일자로 신속민원처리과 신설 등을 주요 내용으로 하는 조직개편을 단행하면서 신속민원처리과, 가족정책과,문화예술과,교육체육과,해양산업과 등 5개과를 신설과 중복업를 통합해 조직운영 합리성을 제고하고, 기능이 약해지거나 업무효과가 불확실한 조직은 폐지 또는 축소 했다.',
            '지난 7일 에너지밸리 정례포럼에서  임춘택 한국에너지기술평가원장은 재생에너지를 통한 에너지 자립국가로 나아가야 한다 "고 주장했다.',
            '대구의 프리미엄 라인인 달구벌대로 2호선 라인, 역세권인 만촌역 서한이다음, 청라언던역 서한이다음 모두 주위에 편의시설이 있고, 중심 브랜드 타운라인에 서게 돼 수요자들의 관심이 집중되고 있다.',
            '서울호서예술실용전문학교 반려동물학과 계열 학생들이 7일 관세청장배 탐지견 경진대회의 8개 학교 40개 팀 중 최고의 수상 성적을 내어 종합 우승을 차지하였으며, 해당 학교는 여러 반려견관련학과가 있고, 면접으로만 학생을 선발하고 있다 밝혔다.',
            '숭실호스피탈리티 직업전문학교가 관광분야 전공 신편입생의 원서 접수를 학교 홈페이지나 진학사 어플라이에서 받고 있으며 100% 면접전형으로 진행한다 밝혔다.',
            '국제수영연맹이 주관하는 하이다이빙 예선이 국내에서는 처음으로 조선대 운동장에서 개최돼 국내외 관람객들에게 즐거운 볼거리를 제공했다.',
            '오산시는 보다 나은 행정서비스 제공을 위해 1국 3과를 신설하는 내용의 조직 개편을 시행한다.',
            "딸의 그림을 자신의 인스타그램에 게시해 관심을 끌었던 장범준은 '슈퍼맨이 돌아왔다'에서 딸 장조아 양과 아들 장하다 군과 함께하는 육아 일상을 공개할 예정이다.",
            '농림축산식품부 국립농산품질관리원은 21일 설을 맞아 내달 1일까지 차례상에 오르는 주요 농산물의 원산지 식별 정보 제공 및 원산지 표시 단속을 할 예정이며, 품목별 원산지 식별법은 농관원 홈페이지에 올려 확인할 수 있도록 할 방침이다.',
            '개인사업부터 봉사와 의정활동까지 열정적이었던 전 당진시의회 황선숙 의원이 지난해 6.13 지방선거 이후 위암 투병하다 암세포가 전이되어 향년 59세의 나이로 별세했다.',
            '지자체들의 교통문화를 증진시키기 위한 취지로 실시되는 교통문화지수 실태조사에서 경기도가 전년도 보다 하락한 순위인 7위에 올라 도 차원에서 경각심을 갖고 개선을 위한 노력이 필요하다는 지적이 이어지고 있다.',
            '가정의 달 5월을 맞아 영동천 하상주차장에서 브랜드 이미지를 높이기 위해  MBC 가요 베스트가 열리며 MC 조영구, 조정민 씨의 사회로 설운도, 김혜연, 문희옥, 배일호, 정수라, 강진, 유지나 등 20여 명의 유명 가수들이 총출동해 열정과 희망의 무대를 선보인다.',
            '옥천군은 20개 부서별 소관 부서장이 참석한 가운데 오는 25일까지 5일간 새해 군정업무보고회를 열고 공약과 주요 사업계획을 꼼꼼히 짚어보며 새 출발각오를 다진다.',
            "대한민국 대표팀으로 소집돼 U-20월드컵에서 한국 대표팀의 결승 진출을 견인한 국민영웅 이강인의 할머니 김영례씨는 '강인이가 초등학교 2학년 때 강진에 내려와 축구를 했었다'며 그때도 사람들이 '축구신동'이라고 말했다. ' 고 했다.",
            'ONE Championship 2승을 모두 1라운드 KO승한 권원일(23)이  데뷔 후 가장 어려운 상대 고요 미 마쓰시마(27)와 페더급 경기를 갖는데 세 번째 1라운드 KO승 도전을 해 결과가 주목된다.',
            '수원시는 28일 수원시청 영상회의실에서 수원시의 국제자매결연도시인 러시아 니즈니노브고로드시의 민간대표단 8명과 함께 보다 적극적인 민간경제교류와 협력 활성화 방안을 논의했다.',
            '유학원들은 문턱이 낮은 해외 의대를 통해 한국에서 의사가 될 수 있다 홍보하지만 실제 이를 통해 한국에서 의사가 된 사람은 많지 않다.',
            "광명시에서는 홀몸노인 공동가구 '동행'이라는 저소득 주거취약계층 홀몸노인에게 거주지를 마련해 양질의 주거서비스를 지원하는 '홀몸노인 공동가구 시범사업'을 실시하고 있으며, 외로움과 고독감을 해소해 건강한 노후생활을 영위하는데 도움을 주고자 시행했다 말했고, 공동가구 주변에는 행정복지센터와 종합사회복지관이 있어 경로식당 무료급식과 같은 복지서비스 연계가 용이해 1석2조의 효과를 볼 수 있다.",
            '태풍 다나스가 북상함에 따라 영향권에 들 것으로 보여 2019광주세계수영선수권대회 조직위원회는 21일 태풍이 지나갈 때까지 열리는 오픈워터수영과 수구, 하이다이빙 등 경기와 각종 시설에 대해 만반의 대책을 세우고 있다.',
            '곽대훈 한국당 대구시당 위원장은 패스트트랙으로 인한 국회의 운영이 잠시 중단된 가운데 대구·경북(TK) 자유 한국당 의원들이  지금 중요한 것은 민생경제이니 지역구 의원들의 민생현장 방문을 주문하고 있다 "고 말했다.',
            '경기도북부소방재난본부는 지난 30일 드럼통 폭발화재의 폭발사고는 부주의가 주요원인이라며, 취급 부주의에 의한 인명피해를 예방하기 위해 안전 작업 수칙을 지켜줄 것과 안전장비를 통한 안전 작업 환경을 조성할 것을 강조하였다.',
            '인간다 운 삶, 공존의 시대라는 주제로 진행된 제10회 전국 기초단체장 매니페스트 우수 사례 경진대회에서 시흥시가 지역사회 건강한 놀이문화 확산이라는 주제로 시흥 캠페인을 전개하면서 지역 문화 활성화분야 최우수상을 수상했다.',
            '21일 오전 광주시청 중회의실에서 개최된 인공지능 중심도시 광주 만들기에 역량을 집중하기 위한 이용섭 시장 주재의 회의에서 24개의 각 공공기관은 주요 현안 업무에 대해 상호간 공유하고 소통과 협업체계를 공고히 했다.',
            '제8대 광양시의회가 지난 1년간의 성적표와 주요 의정활동의 성과를 공개하며 앞으로 광양발전과 시민행복이라는 목표를 다졌다.',
            '13일 대구경찰에 따르면 범죄예방진단팀 및 지자체와 함께 안심귀갓길에 대해  전수조사를 실시하여 불안환경에 대해 셉테드 기법을 적용한 환경개선에 나서 보행 안전에 불안감을 주는 주요 구간에 대해 범죄예방협의체 회의를 개최하고, 시민방범단체와 맞춤형 순찰을 실시할 예정이다.',
            '부산에서 가장 오래된 삼국시대 성곽으로 알려진 연제구 배산성은 고고학적 연구 성과를 바탕으로 축조 시기가 7세기 전반~중반으로 파악됐었으나, 5~6세기로 볼 수 있다는 과학적 분석 결과가 나와 이에 부산 고대사 연구에서 주요 유적으로 평가받았다.',
            "경북의 대표적 관광상품인 '2019문경달빛사랑여행'은 모두 5회에 걸쳐 운영될 예정으로 첫 번째 여행이 오는 4월 6일 영신숲에서 출발하며 문경 곳곳의 아르다 운 야행을 즐길 수 있는 곳을 소개할 예정이다.",
            '아프리카돼지열병이 파주와 연천에 이어 김포에서도 발생하는 등 확산이 되자 평택시는 방역 관련 긴급회의를 열고 이종호 부시장은 사전예방을 위해 방역 수준 강화와 주요 행사 취소 또는 연기를 주문했다.',
            '지난 20일 김모씨 등 아이돌보미 160여명이 광주 모 대학 산학협력단 등 4개 기관을 상대로 낸 임금 소송 항소심에서 광주고법 민사2부는 근로자로 인정해 휴일근로수당 등을 지급해야 한다 던 1심 판결을 뒤집고, 임금을 목적으로 기관에 종속적인 관계에서 근로를 제공했다고 볼 수 없다며 원고 패소 판결했다고 밝혔다.',
            '10년 넘게 방치돼 있던 장항선 폐철도가 태양관 발전시설을 갖추고 신재생에에너지를 생산하는 친환경 녹색 공간으로 탈바꿈하여  자전거. 보행자도로를 완공했고 폐철도를 활용한 전국 첫 사례이다.',
            '고농도 미세먼지와 초미세먼지로 전국이 몸살을 앓고 있는 가운데 탈원전정책의 재검토와 보다 강력한 비상저감 조치들이 필요하다.',
            '2012년 여수세계박람회 부지 사후 활용을 두고 민간업체에 매각시켜야 한다, 공공을 위해 활용되어야 한다는 주장으로 나눠져 이견을 좁히지 못하고 있다.',
            '지난해 한국관광공사의 12월 추천 걷기여행길에 선정된 충남 홍성군의 홍주성천년여행길은 홍성역이 걷기여행길의 시종점인 힐링코스로 관광객들의 발길이 줄을 잇고 있는데, 천 년 역사를 둘러볼 수 있는 길을 따라 걷다 보면 현재와 과거가 공존하는 시간여행이 가능하다.',
            '중앙아시아 3개국 순방을 마치고 귀국한 문 대통령은 집무실로 출근하여 참모들로부터 주요 현안들에 대해 보고 받고, 북러간 회담에 관심을 가질 예정이다.',
            '관계당국에 따르면 조명균 통일부 장관이 남북 합의 이행과 관련해 남북 고위급 회담 검토를 언급함에 따라 3일 국가안전보장회의 상임위원회를 열어 북측에 회담을 제안할지 여부와 시점을 주요 의제로 다룰 것으로 보이며, 회담이 열린다면 개성공단과 금강산관광 재개 논의가 유력하다.',
            '신용보증기금은 중소기업이 보다 많은 일자리를 생성하고 고용의 질을 높이기 위한 기업의 일자리 창출 역량평가 결과를 보증심사에 반영하는 제도를 27일부터 도입한다고 밝혔다.',
            '더불어민주당이 내년 총선 공천 심사에서 탈당 감산 기준을 ‘최근 4년 이내 탈당자’로 제한하고, 탈당 횟수는 감산 기준에서 배제하기로 결정하여 상습탈당자도 4년만 지나면 감점을 받지 않게 되어 무분별한 출마에 따른 탈당 경력자들을 엄벌하겠다 던 방침은 크게 변질됐다.',
            '장기침체에서 벗어나려면 해로운 기업을 구조조정하고 경제활동을 제약하는 규제를 없애 자원이 효율적으로 사용되고 개인과 기업의 경제 활동을 유인해야 하는데 일본의 실패를 타산지석으로 삼아야 할 판에 혈세를 퍼붓는 정책을 하겠다 니 답답할 뿐이다.',
            '합덕 소망교회의 최연순 담임목사 간 이식 수술비 5000만 원과 관련 본지 1일  사랑을 나눠주세요 <엄마를 살릴 수만 있다면…> 기사가 보도된 이후 따뜻한 온정의 손길이 계속되고 있다.',
            '평소와 다르게 눈이 가렵다 거나 눈곱이 많이 낀다면 알레르기 유발 물질이 눈의 결막에 붙어 염증을 일으키는 알레르기 결막염을 의심해봐야 하며 추가적으로 눈꺼풀의 가려움, 결막의 충혈, 눈의 화끈거림을 동반한 통증, 눈물흘림 등의 증상이 생겨날 수 있다.',
            '태안군이 민선7기 주요 사업을 추진하고 정부예산을 확보하기 위해 8일 군청 중회의실에서 주요 군정현황 설명회를 열고 지역구의 성일종 국회의원과 협력하여 지역발전을 위해 노력하기로 했다.',
            '자유한국당과 바른미래당은 더불어민주당이 손 의원을 둘러싼 부동산 투기 의혹에 대해 진실 규명을 가로막아 왔다고 주장하며 민주당과 여권을 비난 하고 국정조사를 해야 한다 말했다.',
            '대구시가 24일 시청별관에서 기관 현장 실무책임자들로부터 일자리 현장 체감과 개선점 발굴 등 평가와 의견을 제시받아 일자리 창출 대책에 적극 반영키 위해  "2018년 일자리사업 성과평가 보고회\'를 여는 가운데, 이승호 경제부시장은 "이번 평가를 통해 지금까지의 관 중심 입안자 시각에서 벗어나 수요자 중심 시각에서 시민들이 체감할 수 있는 일자리 정책을 마련하겠다 "고 밝혔다.',
            '어기구 국회의원은 ‘충남지역발전소 주변지역 주민고용 확대방안’ 토론에서 당진화력 지역주민 고용율이 0.9%에 불과한 것에 대해 각 발전사들이 해당 지역주민들의 의견을 수렴해 개선안을 보완해야 하고  발전사들이 지역사회에 대한 책임을 충실히 해야 한다 "고 강조하는 정책토론회를 개최했다.',
            '5·18역사왜곡처벌 광주운동본부가 5·18 망언을 일삼은 자유한국당 3인 국회의원들(김진태, 이종명, 김순례 의원)의 퇴출을 강력히 촉구했다. 요구를 관철하기 위해 오는 9일 전국동시집회를 시작으로 23일 전국범국민대회를 통해 끝까지 투쟁할 것이다 "고 밝혔다.',
            "그룹 아이콘이 오는 7일 발표하는 리패키지 앨범의 트랙리스트를 공개하였으며, 엘범에는 신곡 ‘I’M OK’와  ‘사랑을 했다 ’, ‘죽겠다 ’, ‘이별길' 등 총 23곡이 수록, 또한 아이콘은 오는 6일 서울 송파구 KSPO DOME(올림픽체조경기장)에서 앵콜 콘서트를 진행할 예정이다.",
            '윤경환 관장은 2014년 선수 생활 은퇴 후 당진시체육회 복싱코치로 일하다 복싱의 대중화를 위해 Y복싱클럽을 열고 일반 시민들에게 복싱을 지도해오다 이번에 제22호 당찬사람들로 선정되었다.',
            '매년 해외 어린이들에게 나눔의료를 시행하는 경북대병원이 소아청소년과 김여향 교수의 제의와 경북대병원 공공보건의료사업실 주관으로 지난 4월 17일 2016년 카자흐스탄 선천성 심장병 해외의료봉사 대 수술을 했던 아이다 (여·5)를 초청해 두 번째 수술을 통해 두 개의 심실을 선물했다.',
            '지난 14일 광주시와 광주문화재단은 경제적인 도움을 주고받거나 친목을 도모하기 위해 만든 우리 전래 협동조직인 ‘계’에서 착안해 마련되어 모금액에 1대1 방식으로 이자를 지원하는 방식인 문화예술 펀딩프로젝트인 만만계를 운영한다 밝혔다.',
            '공군에서 연구 개발 중인 항공기를 테스트하는 최초의 여성 개발시험비행 조종사로 선발된 정다정 소령(진)은 2021년 시제 1호기가 나올 한국형 전투기 등 신규 개발 항공기에 탑승해 고난도 임무를 수행하는 정예요원으로 활동하게 된다.',
            '부산 남부경찰서는 전국 최초로 성폭력, 소년범죄, 아동학대 분야 수사에 전담팀을 신설해 13일부터 본격 운영한다고 밝혔으며, 세심한 수사기법이 요구되는 여성·청소년 범죄 수사에 수사 인력의 전문성이 강화돼 사회적 약자들이 보다 안전하게 보호받을 수 있을 것이라고 말했다.',
            '고장 순천시 월등면에서 ‘제16회 순천명품 월등복숭아 체험행사’가 3일과 4일 이틀 동안 월등면행정복지센터와 월등초등학교에서 개최되며,  MBC가요 베스트 축하공연과 복숭아 막걸리, 병조림, 복숭아 당도 맞추기 등 다채로운 체험 프로그램이 준비되어 있다.',
            '대구지방경찰청은 대각선 및 고원식 횡단보도를 교통안전시설 심의를 통과한 매천고 네거리 등 5곳에 추가 설치하는 한편, 보행자를 위협하고 방해하는 행위를 단속하고, 스쿨존 어린이 안전활동과 주요 횡단보도 사고 다발지점에 경찰관을 집중 배치한다고 29일 밝혔다.',
            '광주시가 차세대 지능형 교통시스템 실증사업의 일환으로 오는 2021년까지 주요 간선도로에 C-ITS를 구축한다.',
            '당진시가 당진시장의 100개 공약에 대한 평가와 주요 공약 추진상황을 점검하기 위해 한국매니페스토실천본부에서 추첨과 전화면접 방식으로 선발한 35명을 통해 시민배심원단을 운영한다.',
            '지난 30일 방송된 고품격 토크쇼 MBC ‘라디오스타’에 출연해 “진정한 나를 찾고 자유롭게 살고 있다” 고 근황을 밝힌 오정연은 내가 진짜 뭘 하고 싶었지 생각하다 보니 주위 시선에 신경을 안 쓰고 "직접 지원을 해서 면접을 보고 카페 아르바이트를 하게 되었다"고 말했다.',
            '2019광주세계수영선수권대회 조직위원회에 따르면 종목별 입장권 판매율을 분석한 결과, 하이다이빙이 전체 입장권 판매율 중 96%를 차지해 최고 인기종목인 것으로 나타났다.',
            '채솟값 폭락으로 인해 전남 농민들은 정부의 농산물 수급정책 실패에 대해 성토하면서 성난 민심을  표출하고, 최근 불황 여파로 음식점 등에서 채소 수요가 줄어든 것이 주요원인으로 꼽으며 가격 안정화를 위한 근본적인 대책 마련을 촉구하고 있다.',
            '미세먼지가 주요 사회문제로 부각되면서 2009년 10건에 불과하던 미세먼지 측정기술 관련 특허출원 건수는 지난해 129건을 기록하여 10년 사이 13배 정도 급증하였다.',
            '광주·전남 지역에 장마전선과 북상 중인 제5호 태풍 ‘다나스(DANAS)’의 영향으로 인해 이번 대회 최대 흥행 종목인 하이다이빙 경이를 포함해 2019 광주세계수영선수권대회에 비상이 걸려  조직위 시설팀 한 관계자는 “태풍의 경로가 유동적이기 때문에 우리나라를 피해 가길 바라고 있다”며 “당일 날씨 상태를 확인해 FINA 기술위원들이 진행 상황을 결정할 것으로 보인다."고 밝혔다.',
            "광주시의회 이경호 의원은 19일 문화관광 체육실 추경안 심의에서 ''e스포츠 상설 경기장이 ‘반쪽짜리’ 경기장으로 전락할 우려가 있다 ''며 광주시가 경기장에 연간 12억 원의 운영비를 부담하나 매출액 산정의 명확한 기준을 세우지 않았다고 지적했다.",
            '최근 미국 그랜드캐년을 여행하다 추락해 의식불명에 빠진 박준혁 씨의 사연이 알려졌는데 관광회사 측은 박씨가 안전지시를 따르지 않았다고 주장하는 반면 박씨 가족들은 평소 신중한 성격의 박씨가 안전지시를 따랐을 것이라는 주장을 하고 있으며 이 같은 사연이 담긴 국민청원에 22일 현재 1만1600여 명이 동의했다.',
            "경기도와 경기도경제과학진흥원이 주관하는 '2019 공유기업 발굴 & 육성 사업'의 지원을 받는 온다 루프는 유휴공간인 루프탑을 활용하고 싶은 소유주와 이용하고 싶은 소비자들에게 위치기반으로 대여 가능한 루프탑 정보를 매칭해주는 옥상공유 플랫폼이다.",
            'MBC에브리원 \'비디오스타\'는 9일 방송에서  \'개척자 특집, 방송가 콜럼버스의 재림\'으로 꾸며져 1999년 "남희석 이휘재의 한국이 보인다 \'로 인기를 얻은 1세대 외국인 방송인 브루노와 보쳉 그리고 김장훈, 임은경이 출연했다.',
            '전남 목포시가 등록문화재 제696호 목포 정광정혜원을 5개월에 걸쳐 보존 및 활용 종합정비계획을 수립해 건물 원형복원 계획 수립과 정밀 안전진단, 실측도면 작성을 주요 내용으로 체계적 관리에 나선다.',
            '경기도는 2018년부터 2022년까지 교통약자 및 보행자가 보다 안전하고 편리하게 이동할 수 있는 도로·교통 환경 조성을 위해 총 105억 원의 도비를 투자한다.',
            '광주북부경찰서는 9일 윤창호법 시행으로 음주운전단속이 강화된 가운데 광주에서 음주상태로 운전을 하다 사고를 낸 무면허 운전자를 구속하고 차량까지 몰수하였으며 운전자들은 경각심을 일깨우지 않고 사고가 잇따라 적극적으로 차량 압수 조치를 시행할 예정이라고 밝혔다.',
            '추경호 의원은 근로시간 단축 위반 사업장에 처벌유예기간이 종료된 것과 관련해 탄력근로제 단위기간 확대 등 보완적 입법조치가 마련될 때까지 위반 사업장에 대한 처벌을 유예해야 한다 ”고 주장했고 근로감독을 실시 계획으로 최저임금 인상으로 인한 고용대란과 소득분배 악화를 해소하기 위해 내년도 최저임금 동결을 강력히 촉구한다”고 밝혔다.',
            '경남 밀양강 둔치 특설경기장에서 열린 제1회 밀양시장배 전국승마대회에서 고령군 대가야기마문화체험장 대가야유소년승마단이 권승경기, 거북이달린다, 릴레이코스경기 등 여러 종목에서 4명이 출전해 창단 1년만에 전원 입상하는 쾌거를 거뒀다.',
            '지난해 9월 27일 오후 6시 20분에 대구시 북구 도로에서 음주운전을 하다 주변에 있는 차를 들이받고 달아나다 붙잡힌 A씨가 지난해 12월 5일 대구지검에 조사를 받으러 가면서도 검찰청 민원인 주차장까지 음주운전을 하여 대구지검이 상습적으로 음주운전을 한 혐의로 구속하기로 했다.',
            '여름 휴가철을 맞아 전국의 해수욕장에서 바가지요금 단속이 추진되나, 단속 효과는 미비할 것으로 보여 현실적인 대책 마련이 필요하다.',
            '11일 여수시의회에 따르면 지난해 7월 9일 개원한 제7대 여수시의회는 1년간 46건의 조례안을 발의하며 개원 후 어느 때보다도 적극적인 의정활동을 한 것으로 전했으나 다만 위원회 구성과 주요 사안의 견해차로 의원 간 심각한 대립을 노출했던 점은 풀어야 할 숙제라는 분석이다.',
            '20일 잡코리아는 인천공항운영관리가 21일까지 각 분야별 정규직 및 계약직 직원을, 펄어비스도 주요 분야 직원을 채용한다고 밝혔다.',
            '자유 한국당 송언석 의원은 28일 우리나라 경제성장률이 10년 만에 최저치 도달이 좌파식 경제 실험이냐고 따졌으며 대통령 취임식에서 언급한 ‘한 번도 경험해보지 못한 나라’의 종착점이 ‘모두 함께 힘들게 사는 나라’는 아니지 않는가? ”라고 반문하면서 기업의 기(氣)를 북도우는 정책을 추진해 국가 경제회복에 앞장서야 한다”고 주장했다.',
            '조아-하다 남매와 아내 송승아 씨가 자외선 차단을 위해 궁중비책 선쿠션을 바르는 일상을 담은 궁중비책 광고 영상이 열흘 만에 유튜브 35만 조회수를 기록하며 화제가 되고 있다.',
            "23일 환경부의 ‘4대강 조사·평가 기획위원회’가 전날 금강과 영산강의 보 5개 가운데 3개를 해체하고 2개는 상시 개방하는 안을 제시한 것에 대해 민주·평화·정의 등 범진보진영 정당들은 일제히 환영의 목소리를 내며 합당한 조치라고 평가한 반면  한국당은 비판이지만 바른미래당은 지도부 논의를 거쳐 추후 입장을 발표할 예정이다.",
            "목면초등학교는 21일 목면초등학교 운동장에서 교직원과 학생, 지역주민 200여명이 참가한 가운데, 1919년 4월5일 태극기를 흔들며 만세시위를 하다 일본군의 총탄에 맞아 순국한 목면 출신 권흥규 의사의 숭고한 뜻을 기리기 위해 '순국 100주년 권흥규 의사 제향' 행사를 개최했다.",
            "태안군은 지난 29일 군청 대강당에서 관계자 170여 명이 참석한 가운데 교육 발전과 학생들의 올바른 성장을 위하여 '태안군 사랑 장학회 2019년 장학증서 수여식'을 가졌으며 이날 장학회는 엄격한 심사를 거쳐 선발된 초.중.고. 대학생 161명에게 총 3억800만 원의 장학증서를 수여했다.",
            '대구지역 휘발유값이 5주 간 하락세를 보이다 6주만에 상승하며 1천506.25원을 기록했다.',
            '농촌진흥청의 자료에 따르면 국내에서 유통되는 주요 과일 품종 대다수가 일본 품종인 것으로 나타났다.',
            '18일 서산시는 시의회 제238회 제2차 정례회 5분 발언을 통해 지역 쌀 판매를 등한시하는 대형마트에 문제점을 제기한 안원기 의원과 시 관련 부서의 노력으로 그간 롯데마트 서산점에 여러 번 입·퇴점을 되풀이하다 작년 10월부터 판매 중단됐던 뜸부기 쌀을 최근 재판매를 시작했다고 전했다.',
            '환경부가 제주를 제외한 전국 16개 시·도에서 미세먼지 특별법 시행 이후 처음으로 보다 넓어진 참여 범위와 높아진 기준의 미세먼지 비상저감조치를 실시한다고 언급했으며, 대구·경북에선 처음 경험하는 이번 조치로 혼선이 예상된다.',
            "2020년 1월 16일부터 2023년까지 3년동안 전남도체육회를 이끌어가게 될 회장으로 김재무 전 전남도의회 의장이 당선되었고 안정적인 재정 확보로 '튼튼한 전남체육회'를 만들겠다 '고 밝혀 앞으로의 귀추가 주목된다.",
            '4일 대구시는 내년 예산을 9조 2천345억 원으로 편성해 시의회에 제출했으며, 예산은 장기 미집행 공원일몰제 대응과 주요 SOC 사업 진행에 지방채 발행 증액 등 시민 삶의 질 제고와 지역 경제 활성화를 위해 사용할 예정이다.',
            '이용섭 광주시장은 광주시와 중국과의 우정을 보다 많은 양국 시민들의 만남과 소통을 희망했으며 여름밤을 수놓은 800개의 홍등이 걸린 가운데 치러진 선포식에는 이 시장을 비롯해 각 기관 단체장 등이 참석했다.',
            '한국자살예방협회 및 보건복지부는 자살 예방을 사회적 문제로 인식하여 공동체 노력으로 해결하고자 위험과 예방의 중간다리 역할을 통해 자살 예방에 도움을 주는 사람을 일컫는 생명사랑지킴이 교육을 온 국민을 대상으로 펼치고자 한다.',
            '영화 ‘추격자’가 TV 방영하면서 실시간 검색어에 오르며 관심을 모으고 있는 가운데 한 인터뷰에서 한재덕 대표에게 나홍진 감독 차기작이 우범곤 총기 사건을 모티프로 한다는 그 영화인가? ”라고 질문하자 나홍진 감독과는 구두로 "함께 하자"고 이야기를 나눈 상태라고 답했다.',
            '여수시의회 웅천특위는 지난해 9명으로 구성했으나 3명의 의원의 사퇴로 현재 6명으로 운영되고 있는데 위원 구성문제로 갈등을 겪다 또다시 송하진 의원의 사퇴가 이어졌다.',
            '당진환경운동연합, 참여자치시민연대 등 14개 단체로 구성된 현대제철 대기오염 대책위원회가 출범하여 연간 대기오염물질 배출량 전국 1위를 기록하고 청산가스를 불법 배출하다 적발된 현대제철 당진공장을 고발하였다.',
            '삼성전자는 20일 서울 서초사옥 다목적홀에서 1000여 명이 참석한 가운데 ‘제50기 정기 주주총회’를 개최했으며 김기남 대표이사는 체질개선을 통한 내실 강화를 추진하겠다 "고 강조했다.',
            '제64회 현중일을 맞아 광주시와 전라남도에서는 주요인사와 유족, 시민들이 참여한 가운데 순국선열과 호국영령을 기리는 추념식을 거행해 나라를 위해 헌신한 분들을 추모했다.',
            '지난 12일 3월 14일인 화이트데이를 맞이하여 광주신세계가 지하 1층 식품관과 본관 2층에서 시즌에 맞춘 다양한 상품들을 선보이고 있다 밝혔다.',
            '18일 TV조선 예능 인생감정쇼-얼마에요 에 출연한 모델 박둘선과 사진작가 남편 조장석 부부의 과거 러브스토리가 재조명되고 있다.',
            '가평군 상면에 위치하는 아침고요 수목원이 한국관광 100선에 선정되었으며 3회 연속 국내 대표 관광지로 선정되었다.',
            '유곡리에서 나고 10년 간 공직생활을 하다 결혼 후 30대 초반 다소 늦은 나이에 신학을 배우며 목회활동을 시작한 송악읍 고대리에 위치한 고대감리교회 성일용 담임목사는 1997년 당진시대에 종교칼럼 필진으로, 글을 쓰면서 당진시대와 인연이 닿았다.',
            '당진항만관광공사 ‘천안함 피격사건과 국가 안보의 중요성’을 주제로 개최한 제7회 학생안보글짓기대회에서 운문 분야에서는 한다음(서야고)이 대상을 수상했으며 산문 분야에서는 이여경(송악중)과 김희경(기지초)이 대상을 수상했다.',
            '금융위원회와 금융감동원은 지난 31일 투명성과 공정성을 확보하기 위해 인터넷은행 예비인가에 적용할 주요 평가항목 및 배점을 공개했으며 제반 인가요 건을 충족한 신청자들을 대상으로 외부평가위원회에서 평가를 진행한다.',
            '매일같이 일만 하다 일흔이 됐을 무렵 치매 위험 진단을 받은 박막례 할머니를 위하여 손녀는 함께 떠난 여행에서 찍은 영상을 유튜브에 올렸고 그 영상들의 인기가 나날이 높아지며, 할머니의 인생은 완전히 달라졌다.',
            '27일 공정거래위원회는 가맹사업 희망자들이 반드시 사야 하는 주요 품목의 가격 범위를 미리 공개해야 하는 정보공개서 표준양식을 개정해 28일부터 적용함에 따라 가맹본부는 4월 말까지 정기변경등록시 새 표준양식에 따라 변경 등록을 해야 한다.',
            "아산시는 '2019년 생생문화재 공모사업'에 선정되어 온주아문에서 관야유적을 기반으로 만든 문화재 체험프로그램 '온주아문 다시 수락하다'를 진행하고 사또 양로연이 뭐예요, 온주아문 가족애 통통캠프 등을 운영한다.",
            '벡스코는 25일 글로벌 전시회 육성과 혁신 경영을 추진한다 밝히면서, 대형 전시회가 지역 경제에 미치는 파급력을 고려해 3개 전시회 이외, 기존 주관 전시회의 규모를 확대하는 방안을 검토하고 전담팀을 구축하여 대형 국제회의에서 파생되는 고급 지식이 지역에 체화될 수 있게 지원한다고 하였다.',
            '31일 서울 강서구 제주항공 회의실에서 제주항공과 국민체육진흥공단 관계자 등이 참석한 가운데 업무 수행 능력을 보다 꼼꼼하게 살피기 위한 체력검정에 관한 업무협약을 체결하고 올해 하반기 공개채용부터 국민체육진흥공단이 발급하는 인증서를 활용한다고 31일 밝혔다.',
            '고흥군은 네팔.인도. 카타르 기업대표와 총 150만불의 수출 협약을 체결하고 고흥 농수특산품 수출 및 판매 확대를 위해 상호 간 적극 노력하기로 합의하여 앞으로 수출 확대를 도모할 수 있는 좋은 기회가 될 것으로 기대하고 있으며, 몽골.체코 등 신규 수출 채널 확대에 대비해 수출경쟁력 강화에 힘쓰겠다고 밝혔다.',
            "지난 14일 서울 리베라호텔에서 열린 '2020 여자실업핸드볼 신입 드래프트'에서 광주시체육회는 사방 돌파 능려깅 탁월하다 정평이 나있는 방민서를 지명했다.",
            '금융감독원이 다음 달 1일부터 상속인 금융거래 조회서비스를 개선해 개인연금보험 가입자가 사망했을 때 상속인이 받을 수 있는 연금 정보를 보다 쉽게 확인할 수 있도록 조회서비스를 개선한다고 밝혔다.',
            '5·18역사왜곡처벌 광주운동본부와 민주노총 광주본부는 지난 14일 자유한국당 전당대회장에서 ‘5·18 망언’ 의원을 규탄하다 입건된 노조 조합원·학생의 구속영장 철회를 촉구하며 구속영장을 청구한 것은 명백히 과도한 법 집행이자 민주주의에 대한 도전이라고 강조했다.',
            "오는 28일 인천시 동구 동인천역 북광장과 송림아뜨렛길에서는 동구문화예술제와 연계한 '지역 문화예술인들과 함께하는 막걸리 페스티벌'을 개최하며, 공예품 체험 및 판매 뿐만 아니라 가요 ·민요 공연이 준비될 예정이다.",
            '스티브 로뷰(34·미국)와 아드리아나 히메네스(33·멕시코)는 국제수영연맹(FINA)에 의해서 2013년 바르셀로나 대회부터 정식 채택된 하이다이빙 종목에서 화려한 연기를 펼치며 각각 남자부와 여자부에서 우승을 향해 나아갔다.',
            "하남시 나룰도서관은 17일 오후7시에 <글쓰기의 최전선>, <글기의 말들>, <싸울 때마다 투명해진다> 등 여러 베스트셀러를 집필한 은유 작가를 강사로 초청해 ‘이해와 공감의 글쓰기’라는 주제로 '제46회 나를 찾는 삶의 인문학' 강연을 진행한다.",
            "선안군은 오는 7일부터 임자도에서 '섬 깡다리' 축제를 개최해 깡다리 요리 및 시식회, 깡다리 가요 제 등 다양한 프로그램이 열리며 관광객들을 위한 직거래 판매코너와 홍보전시관을 운영한다.",
            '도교육청 정책기획관은 22일 브리핑룸에서 출입기자들을 대상으로 정책에 대한 이해도를 높이고자 여러 관계자들이 모인 자리에서 정책기획관 설명회를 열고 올해 추진하는 주요 정책과 현안사업 등에 대해 소개하였다.',
            '2017년 헝가리 부다페스트대회 하이다이빙에서 1위를 차지한 호주 선수 리아난 이프랜드가 광주세계수영선수대회에서도 1위에 오르며 2연패를 달성하였다.',
            '화장실에서 벌을 서다 숨진 4살 어린이를 양육한 부모가 학대 혐의로 처벌받은 적이 있고 피해 어린이의 야윈 몸과 여러 상처로 미루어 봤을때 열약한 가정환경에서 지속적으로 학대를 당했을 것으로 판단할 수 있다.',
            "정부는 지자체의 무허가 축사 적법화 담당자가 행정집행을 하다 불이익을 받는 일이 없도록 농림축산식품부 등 5개 부처 장관이 합동으로 서명한 '무허가 축사 적법화 추진을 위한 협조문'을 21일 광역·기초지자체장에게 보내기로 했다.",
            '부산에서 경찰의 대대적인 단속에도 불구하고 장거리 승객이 몰리는 주요 지점에서 일부 택시가 무리를 형성해 영업권을 독점하는 문제가 계속 되고 있다.',
            '13일 시교육청에 따르면 교실 공기 질 개선을 위해 겨울방학기간 36억원, 올해말까지 168억원을 투입해 대구 유.초.중.고. 특수학교 전 학급에 공기정화장치를 보급한다.',
            '부석면발전협의회는 18일 저녁 부석면행정복지센터에서 긴급회의를 열어 보험금만 70억원에 달하는 천수만 B지구 간척지 염해 피해는 현대농장이 보를 트면서 생긴 인재이며 경작자피해대책위를 꾸려 피해와 관련한 대응을 하기로 했다.',
            '세종시의 시민단체인 행정수도완성 시민대책위원회는 장차관의 공석으로 의사결정 지연 등의 문제가 생기는 세종청사 장차관 서울집무실을 폐지하는 방안에 긍정적으로 평가했지만 보다 근본적인 대책으로 대통령의 세종집무실을 설치할 것을 요청하였다.',
            '경기도 주요 복지정책 예산이 경기도의회 상임위원회의 1차 심의를 통과해 예산결산특별위원회로 넘어가 내년도 경기도형 복지사업이 활성화될 것으로 기대된다.',
            "팬스타그룹(회장 김현겸)은 1일 그룹 항운사업 총괄 겸 (주)팬스타신항국제물류센터 대표이사에  경제기획원, 해양수산부, 부산 지방해양 수산청장, 해양환경 관리공단 이사장 등의 경력을 가진 곽인섭 전 한중훼리 대표를 선임했으며 또한 (주)팬스타트리 대표를 겸임한다 '고 발표했다.",
            '캄보디아 프놈펜으로 봉사활동을 실시하다 복통을 호소한 건양대 학생 2명은 병원에서 치료를 받던 중 9일 오후, 10일 오전 각각 사망했다.',
            '전남대학교는 1980년 시민군으로 활동하다 5월27일 새벽 계엄군의 전남도청 진압을 막기 위해 최후까지 저항하다 총상을 입고 사망한 고 유영선씨의 명예졸업증서를 유족 고인의 형수 신애덕씨에게 2018학년도 전기학위수여식에서 전달했다.',
            '2019광주세계수영선수권대회를 위해 임시시설로 설치한 경기장을 철거하게 되면서 많은 사람들이 아쉬움을 표현했으며, 가장 먼저 하이다이빙 경기장이 철거될 계획이다.',
            '전남 순천경찰서는 도피생활 중 중국 본사 책임자와 연락하며 도박사이트를 새롭게 개설해 운영하다 검거된 총책 P(42), 각각 전남 일대 도박사이트를 관리하던 전남지사 관리책, 광양 도박장 운영자 P씨와 Y씨 등 일당 3명을 150억 대 사이버 도박장을 개설해 도박공간을 제공한 혐의 등으로 붙잡아 조사하고 있다고 17일 밝혔다.',
            '전남도 해양수산기술원이 설 명절을 앞두고 수요가 증가될 것으로 예상되는 주요 수산물에 대해 방사능, 중금속, 항생제, 환경 오염 물질 등의 안전성 조사를 대폭 강화한다',
            "광주시 동구는 '아이 키우기 좋은 동구'를 목표로 생활환경.안전.교육환경.보건복지. 놀이권 보장을 위한 5대 분야별 '동구형 아동친화도시 종합계획을 수립하였으며, 계획에는 5대영역 20개 아동친화도시 세부사업이 포함됐다.",
            '학위 취득 유예제가 감소하고있다. 학생들의 경우 졸업을 늦춰봤다 들어가는 비용과 비교해 실익이 없고 학교의 경우 교수 1인당 학생 수가 늘어나 각종 평가에서 불리한 요인이 될 있기 때문인것으로 보인다.',
            '인천의 사립유치원 248곳 중 44.4%에 해당하는 110곳이 유치원 회계로 만기환급형 보험금을 납부하다 적발됐으며 이에 감사원은 변칙 적립 용도로 사용한 보험금을 세입처리하라고 요청했다.',
            '2019광주세계수영선수권대회가 초반의 부진을 딛고 대회 인기종목인 경영과 하이다이빙 경기에서 입장객 누계 20만명을 돌파하는 등 막판 흥행 열기를 이어가고 있으며 세계신기록 달성을 비롯한 스타 플레이어들의 금빛 레이스, 새로운 슈퍼 루키 등장 등이 연출되면서 관심이 높아진 것으로 분석되고 있다.',
            "30일 북구가 65세 이상 독거 노인과 1인가구를 대상으로 고독사를 예방하는 '모바일 안심 돌봄서비스'를 운영한다 밝혔으며 7월 중 모바일 모니터링 시스템 구축을 완료할 예정이다.",
            '당진시가 평생학습체육과로 평생학습을 변경하면서 평생교육팀이 전담해 오던 업무를 분리하여 평생교육 프로그램의 운영과 지원을 보다 체계적으로 추진할 계획이라고 하면서 한단계 업그레이드 된 평생학습을 선보일 예정이다.',
            "8일 오후 방송되는 MBC '생방송 오늘저녁'은 나 혼자 간다 코너를 통해 거제 여행을, 가화맛사성 코너를 통해 52년 전통, 홍어 한상 맛집을 소개한다.",
            '장마철에 접어들면서 고온다습한 날씨가 이어질 것으로 예상됨에 따라 음식 적게 조리해 바로 먹기, 어패류 반드시 익혀먹기, 청결한 손씻기 등으로 식중독 예방에 신경써야한다.',
            '송산면 유곡리 이장 최승영 씨와 아내 김귀선 씨, 아들 최재민 씨가 운영하는 식당 온다 미로와 카페 하인츠는 감각적인 콘테이너 하우스로 지어져 관광객들을 초대하고 있다.',
            '대구지방기상청에 따르면 주말 대구,경북은 일본 오키나와 남쪽 약 470km 부근 해상에서 발생한 타파의 영향권에 들면서 많은 양의 비가 내릴 전망이며, 21일에는 북쪽 상공에서 남하하는 찬 공기와 태풍에 의해 유입되는 남쪽의 고온다습한 공기가 만나 발생한 강한 비 구름대의 영향을 받는다.',
            '경주시의회가 오는 19일까지 제239회 임시회를 열어 상임위원회별로 주요  현장방문, 조례 심의, 경주시의 올해 주요업무에 대해 보고받고, 주요 조례안을 심의하며 시민들의 의견을 최대한 시정에 반영하기 위해 노력하고 있다.',
            "인천시 옹진군은 도서지역 자립을 위한 도서특성화 사업을 진행하며 향토음식 및 지역 특산품을 개발하여 관광객과 섬 주민 모두에게 이익이 되는 일석이조의 사업을 활성화 할 수 있도록 지원하겠다 '고 밝혔다.",
            '이재명 경기도지사는 지방자치의 내실화를 위한 경기북부 분도는 필요하나 시기상조라고 선을 긋고 내년의 도 주요 사업으로 지역화폐, 일자리 창출 등을 꼽았다.',
            '올해 중·만생종 양파 생산량이 크게 증가할 것으로 예상되면서 농협 등 관련 기관들이 주요 수출국에 대한 판촉 지원과 소포장 판매 등 수출 확대 방안을 논의했다.',
            "(재)군포문화재단이 수리산상상마을에서 진행하는 미디어아트 기획전시 '모두 잠든 밤, 빛을 주우러 가자'가 어린이들에게 새로운 경험의 기회를 제공하여 일 평균 240명의 관람객이 찾았고. 오픈 40여일 만에 관람객 수 1만 명을 넘었다.",
            '영동군은 12일 A형 간염 충청권 확산에 따라 주요 발생연령대인 30~40대에게 예방을 위해 각별한 주의를 당부했다.',
            '순천시는 타지역에 거주하다 순천에 터를 잡고 살게 된 이야기를 공모전을 통해 모으고, 옛 선조인 입향 성씨(入鄕 姓氏)에 대한 내용으로 함께 구성한 ‘순천에 뿌리내린 사람들’이라는 정착 사례집을 발간했는데, 순천 방문의 해를 맞아 전국의 관계 기관, 도서관 등에 배포될 예정이다.',
            '2019 광주세계수영선수권대회가 중반을 넘어서면서 경영과 하이다이빙에 많은 관중이 몰리며 초반 흥행 부진에서 벗어나 폐막일인 28일까지 막판 흥행몰이를 할 것으로 보인다.',
            "손혜원 의원은 목포 부동산 투기 의혹을 처음 보도한 SBS 기자 9명을 고소하고, SBS ‘끝까지 판다’ 에서 손 의원이 차명 구입해 4배 이상 시세차익을 봤다 '는 취지의 보도를 다룬 것에 대해 이는 명백한 허위사실이라고 주장하며 SBS와 양측의 공방이 이어지고 있다.",
            '이용섭 광주시장은 공공기관의 설립목적을 설명하며 시민들이 공감하는 획기적인 성과를 창출하는 공공기관에 대해서 반드시 보상을 하겠다 말했고, 공공기관의 혁신과 소통을 강조했다.',
            '광주광역시는 수영대회에 대비해 광주의 맛, 흥, 멋, 정, 어울림의 다섯가지 매력을 소개한 책자와 주요 관광지 및 7~8월 축제·문화예술행사를 담은 관광안내지도 10만부를 새로 제작해 배부할 계획이라고 5일 밝혔다.',
            '보령시가 올해부터 추진 중인 스마트 마을방송이 서비스 개시 1개월 만에 시민들로부터 높은 호응을 얻고 있는 가운데, 시는 노후된 마을방송 장비 개선 건의와 가정 내 수신기 설치 요구를 수용하여 고효율 저비용의 스마트 마을 방송을 도입하기 위해 지난해 1회 추경 예산을 편성하여 시스템을 구축하고 올해부터 시간과 장소의 제약 없이 주요 시정정보를 신속하게 제공하게 되었으며, 향후 5년 이내에 공동주택을 제외한 전 마을로 서비스를 확대 보급할 수 있도록 적극 검토하겠다고 밝혔다.',
            '지난 11일 한국자동차산업협회와 한국수입자동차협회에 따르면 지난해 11월부터 지난달까지 수입차가 강세를 보이던 고급 자동차 시장에서 대표적인 국산 대형 고급세단의 판매가 뚜렷한 성장세를 보였다 밝혔다.',
            '민주평화당 김경진 의원이 타다 금지법을 지난 12일 발표해 11인~15인승 승합자동차를 임차할 때에는 단체관광이 목적인 경우에만 운전자를 알선할 수 있도록 규정했다.',
            '동절기 철새에 의한 AI 국내유입 가능성이 높아짐에 따라, 경기도는 AI 발생 사전 차단을 위해 오는 27일부터 9월 5일까지 4차례에 걸쳐 AI 특별방역대책기간 대비 가금류 방역교육을 실시한다 밝혔으며, 교육은 AI 방역정책, 국내외 AI 발생 동향 및 분석, 축종별 특성에 맞는 예찰 및 소독요령, 휴업보상, 사양관리방법 등을 내용으로 진행될 예정이다.',
            '신인 걸그룹 ITZY(있지)가 기존 K-팝의 형식을 깨고 새롭게 제작한 퓨전 그루브 장르의 타이틀곡 ‘달라달라’로 가요 계 데뷔를 예고했다.',
            '문재인 대통령은 24일에 나선 전국경제투어에서 "4차산업혁명 시대를 향한 여러분의 꿈에는 늘 정부가 함께 할 것"이라고 강조하며, 신기술을 통한 혁신성장이 한국 경제의 체질을 개선하여 경제활력 제고 및 신성장동력 확보를 모색할 수 있다 판단한 것으로 보인다.',
            "인천시와 인천시의회, 인천시지하도상가연합회 등이 '인천시 지하도상가 관리 운영 조례 전부개정 조례안'을 임시회가 아닌 다음 달에 열리는 시의회에서 다루기로 일정을 미루어서 지하도상가 운영의 공정성을 확보하겠다 던 인천시의 계획이 연기되었다.",
            '조선대병원이 운영하는 ‘2019 광주세계수영선수권대회’ 의료지원단은 응급의학과, 내과, 외과, 정형외과, 영상의학과, 재활의학과, 간호부 등 총 140여 명으로 구성돼 선수촌 메디컬센터와 의무실, 조선대 하이다이빙 경기장, 염주체육관에서 빈틈 없는 의료지원을 통한 수준 높은 의료서비스로 선수 부상과 안전관리에 최선을 다할 것을 다짐했다.',
            '수원 A초 학부모들이 23일 경기도교육청 앞에서 기자회견을 열고  "규정을 지키지 않는 석면 해체 제거 공사를 중단하라"고  요구하며 A초교 본관동 석면 해체 및 제거 작업을 모니터링하던중 대다수 작업장에서 석면이 비산된 것을 발견했다 "고 주장, 올 겨울방학 동안 석면 해체·제거 공사가 진행될 예정인 수원지역 초·중·고 17개 교에 석면 해체 및 제거 시 관리·감독 기능 강화와 감시체계를 만들어야 한다"고 밝혔다.',
            '올해로 65세, 181cm의 큰 키에 자유분방하게 기른 머리카락과 수염을 가진 모델 김칠두는 27년 동안 요식업에 종사하다 작년에야 시작한 모델일이 즐겁지만 굉장히 어렵다고 했다.',
            '강화군은 돼지열병으로 입은 피해를 복구하기 위해 관광객 유입 홍보와 다방면으로 대책을 강구하고 있으나, 인접지역 김포시의 방역활동으로 인해 피해를 받고 있어, 이에 김포시 축산팀에서는 ASF 업무 매뉴얼 지침에 따라 방역을 하고 있다 해명했지만 강화군의 관광활성화가 무색해지고 있다.',
            '홍성군은 다음달까지 대규모 공사장을 중심으로 미세먼지 발생 핵심현장에 대한 특별점검활동과 위생업소 250개소를 집중관리하는 등 미세먼지 등 환경분야, 안전 먹거리 확보 분야, 재난 안전 인프라 구축 등 군민 생활을 위협하는 위해요 소 차단을 위한 종합대책을 마련했다.',
            '다이텍 연구원은 12일 고강도 원지를 이용한 벽지 제조 기술과 방충성, 항균성, 항곰팡이성의 기능성 코팅 수지 개발 기술을 확보함으로써 고온다습한 환경에서도 형태안정성이 확보되고, 방충 성능이 우수한 ‘기능성 디자인 벽지’ 개발에 성공했으며, 동남아 인테리어 시장확대가 기대된다고 밝혔다.',
            '2019광주세계수영선수권대회 조직위원회는 대회 개막 14일 전인 지난 6월 28일까지 대회 입장권 판매가 목표판매량의 88%를 달성했으며 하이다이빙, 오픈워터 수영 종목은 이미 매진됐다고 밝히며 입장권 매진사태가 벌어질 수도 있는 만큼 시민들의 신속한 입장권 구매를 부탁했다.',
            '시와 국회의원측이 주요 현안사업과 향후 국비 확보 추진 전략에 대해 논의하여 서로 협력해 나가기로 했으며 그에 따라 시는 사업 발굴에 주력한 뒤 주요 사업에 대한 국비 지원을 건의할 계획이다.',
            '14일 동구청역에서 음주로 몸을 가누지 못하다 쓰러진 노인(남,72세)을 역 직원이 응급구호 조치를 빠르게 실시한 덕분에 병원에 도착 후 뇌출혈 수술을 받은 뒤 좋은 경과를 내고 있다는 사실이 가족들의 제보로 뒤늦게 밝혀졌다.',
            '14일 보건복지부와 건강보험공단에 따르면 3월부터 추나요법에 대해 건강보험이 적용됨에 따라 추나요법 치료에 회당 1만∼3만원의 본인부담금을 지불하고 연간 20회까지 받을 수 있다.',
            '500명의 신청자 중 150명에 선정된 제7기 통일부어린이 기자 중 통일부 장관과의 만남을 주제로 한 인터뷰 기사를 써서 우수기사로 선정된 계성초 5학년 이다 은 학생은 앞으로 친구들도 공감할 수 있는 기사를 쓰고 싶다고 소감을 밝혔다.',
            "예산군에 따르면 장애인에 대한 인식 제고와 사회 참여확대로 재활의욕을 고취하고 장애인과 비장애인이 함께하는 사회 통합분위기를 마련하기 위해 '제39회 충남 장애인의 날' 기념식과 15개 시·군을 대표한 장애인들이 참여하는 장애인가요 제를 비롯한 장애인생산품 전시, 장애인과 가족을 위한 상담 부스 운영 등 다양한 부대행사로 진행한 '희망충남 어울림 한마당대회'가 성황리에 개최됐다.",
            '22일 이시종 지사는 증평군청 대회의실에서 열린 200여 명과의 증평군민과 대화 시간에 주요 도정 성과에 대해 설명하고 증평경찰서·종합운동장 조성을 적극 지원하겠다고 밝혔다.',
            '지난 24일 인천국제공항에서 입국사유 불분명으로 입국이 거절돼 송환대기 중이던 외국인 3명이 입국장 화장실 천장을 열고 환풍구 통로로 밀입국을 시도하다 붙잡혀 강제 출국 조치될 예정이다.',
            '고민정 청와대 대변인은 8일 문대통령의 G20 정상회의에서 주요 의회에 불참했다는 내용의 영상이 온라인에 퍼지는 것에 거짓 정보들이 너무 많아 열거하기 힘들 정도라고 비판하며 영상을 만든 사람이 기자였다면 이렇게 만들지 못했을 것이라고 부연했다.',
            "29일 KBS '오늘밤 김제동'에 출연한 전 수영 국가대표 장희진 선수는 2000년 시드니 올림픽을 앞두고 중학생때 대표선수로 선발된 후, 중간고사를 위해 선수촌 밖에서의 훈련을 요구하다 국가대표 자격을 박탈당하고 유학길에 올라 현재 미국에 거주하며 변호사로 지내고 있는 근황을 알렸다.",
            '대학원 입시와 전문연구요원 편입을 목적으로 텝스(TEPS) 시험 준비생들이 많아진 가운데, 실전 대비에 큰 효과를 준다고 알려진 해커스어학원이 뉴텝스를 준비할 수 있는 실전 문제풀이 특강을 실시한다고 해 큰 관심을 받고 있다.',
            '전남 신안군 임자면 지역사회보장협의체는 인근 민간사회단체, 사회복지시설, 종교단체의 적극적인 참여와 함께 지난 4월 29일부터 5월 17일까지 아프리카 우간다 및 인도 아이들에게 의류·신발, 책가방을 전하기 위해 ‘선물이 간다간다 우간다’ 기부운동을 펼쳐 500점을 기부 받았다.',
            "KBSTV 에서 신선한 기획으로 화제를 일으킨 파일럿 모큐멘터리 '회사가기 싫어' 가 새롭게 12부작 초밀착 오피스 드라마로 더 풍성하고 진정성 있는 스토리 라인으로 펼쳐지며, 극중 한다 스 오피스의 '최영수' 부장역을 맡은 '이황의'는 명품 연기로 안방 시청자들의 공감을 이끌어 낼 예정이다.",
            '광주시교육청은 주요 교육현안과 관련해 공론화로 이뤄진 합의 내용을 교육감에게 권고하는 역할을 해줄 광주 교육 시민 참여단 30명의 구성이 완료되었다고 17일 밝혔다.',
            "8일 방송 예정인 KBS 2TV '배틀트립'에 샤이니 키, 남창희, 한다 감, 허영지, SF9 로운이 출연해 '혼자 떠나는 여행'이라는 주제로 혼자하는 여행을 설계하고 여행지의 메뉴를 소개한다.",
            '광주를 찾는 국내외 방문객들이 주요 경기장, 관광지를 안내하는 표지 및 대중교통 안내가 없어 불편을 호소했다.',
            "3일 프로텍트엠이 일반 액정 보호 필름과 다르게 온스크린 지문인식에 대응할 수 있도록 제작한 '갤럭시S10 시리즈 전용 강화유리'와 '보호필름' 14종을 출시한다 밝혔다.",
            '김영국 대전 회덕농협 조합장이 자진사퇴한 회덕농협은 내달 4일 보궐 선거를 치러야하는 데다 김 전 조합장 및 일부 조합원이 검찰의 수사를 받는 등 후폭풍이 불 전망이다.',
            "밀양가요 박물관 건립을 놓고, 밀양가요 박물관건립저지시민연합은 '친일파 박시춘을 중심으로 박물관을 건립하는 것은 사실상 친일 인사 기념관 건립과 마찬가지'라며 건립 계획을 즉시 백지화하라고 요구했다.",
            '신안군, 우간다 ·인도에 의류·신발·책가방 등 기부운동을 시작해 눈길을 끌고 있다.',
            '광주·전남지방중소기벤처기업청과 광주사회적경제지원센터는 사회적 목적 추구와 수익을 창출하는 사회적 경제기업이 일반 중소기업에 보다 경쟁력이 열악함에 따라 수출 지원을 통해 성장을 돕겠다고 밝혔다.',
            '광주시의회 김점기 의원은 광주김치타운에 내 김치공장이 임대 전 시설 보수 및 보강을 하지 않아 위생상태 불량으로 평가받아 ‘0’점 처리가 돼 학교 납품업체 선정 부적격 평가를 받았다 ”고 밝히며 “광주 학생들에게조차 공급하지 못하는 김치를 전국화, 세계화하겠다는 것은 어불성설"이라고 지적했다.',
            '군위군은 주요 관광지 25곳을 한눈에 쏙 들어오게 세 개의 코스로 나눠 하루만에 관광할 수 있도록 제작한 관광안내지도를 고속도로 휴게소 등에 배부하고 대대적인 홍보에 나선다.',
            '인천항만공사(IPA)는 온라인 소통 채널을 통해 국민 참여를 확대하고 다양한 아이디어를 제안받고자 ‘e-해해(海) 소셜네트워크(SNS) 플랫폼’을 오픈했으며, 국민 참여 제안과제 발굴과 이해관계자별 일대일 맞춤형 소통, 국민 참여형 인천항 안전 위해요 소 실시간 접수·운영 채널 3개 분야로 운영한다.',
            '더불어민주당이 내년 4월 총선 대비를 준비하고 있고 상당폭의 물갈이가 이뤄질거라는 전망이 나오는 가운데 공천의 주관적인 평가요 소로 인해 물갈이 대상을 의도적으로 컷오프를 할 수 있다는 분석이다.',
            'EBS에서 유명세를 치른 뒤 현재 메가스터디에서 활동 중인 이다 지 강사와 고아름 강사가 교재 도용 문제로 설전을 벌였는데 이 강사는 고 강사가 학생들에게 제공한 연표를 제시하면서 오탈자 표기된 것까지 똑같다고 했다.',
            "세종 조치원 봄꽃축제가 '청춘만발-조치원의 봄, 문화의 꽃을 피우다'를 주제로 4월 6일부터 7일까지 이틀간 조치원역과 중심가로, 조천변 일원에서 성대하게 열리며 벚꽃과 복사꽃을 배경으로 마련된 4개의 테마공간에서 개막 축하공연과 미디어 불꽃쇼, 봄꽃가요 제, 낭만시장, 청춘마켓, 버스킹 공연과 다양한 문화예술 프로그램이 진행될 예정이다.",
            '포르투갈 출신의 하이다이빙 안전요원의 임무는 높은 곳에서 안전하게 연기하는 선수들에게 심리적 안정감을 주는 일이다.',
            '논산시는 19일에 웰빙을 넘어 웰다잉으로 \'아름다운 노년만들기\'에 나섰다. \'웰다잉 전문 지도자\'교육은 고령화시대에 맞춰 건강한 노후를 추구, 삶의 가치 및 생명존중 문화 확산을 통한 건강한 지역사회를 구현하기 뒤한 직원 연량 강화 교육이다. 이에 논산시보건소 관계자는 "초고령화로 가는 현재\'웰빙, 웰다잉\' 웰에이징\'할 수 있도록 도와주는 존재는 필수이며 "전문 지도자 양성을 통해 행복한 노후를 응원하고, 안내할 수 있도록 최선을 다하겠다 "고 말하였다.',
            '송악읍 중흥리에 지난 2015년 착공한 광명메이루즈 아파트는 업체 부도로 골조공사를 50% 가량 진행하다 중단되면서 해당 사업을 경남기업과 티케이케미칼이 인수하여 경남아너스빌 아파트 건설을 추진하고 있으나 당시 지역업체들이 철근과 레미콘, 자재 등의 납품 대가를 돌려받지 못하는 상황이 계속돼왔다.',
            '김광진 원예특작원 연구관은 미세먼지대책으로 발생원을 축소하는 데에 주력하느라 일상 속 ‘자연과의 공존’은 놓치고 있는 실정으로 "식물 동반환경 조성” 강조하며 자연을 대신할 수 있는 원예가 곧 생활이 돼야 한다 "고 전했다.',
            '아프리카 열병이 퍼지면서 삼겹살의 가격이 오르는 데다 휘발유와 소주 값까지 오르게 되면서, 지갑이 얇아지는 5월을 맞은 서민들은 이중고를 앓고 있다.',
            '2022학년 수능은 2015개정 교육과정의 의도에 따라 문이과의 구분이 사라지며 제2외국어. 한문 영역이 절대평가로 바뀌었습니다',
            '망곔소리는 대한민국의 강토를 악보로 하고, 민족의 역사를 노래하는 강산민요로, 충남보존회가 월요일과 금요일 오후 5시부터 7시, 오후 7시부터 9시까지 민요 수업을 진행할 예정이다.',
            '대구는 19일 DGB대구은행파크에서 열린 프로축구 K리그1 12라운드 인천 유나이티전에서 전반 세징야의 선제골과 후반 에드가의 결승골로 2-1 승리하며 선두권 도약의 발판을 마련하게 됐다.',
            '‘문제적 보스’에 출연하는 배우 정준호는 패션, 웨딩, 뷔페 등의 다양한 분야에서 사업을 하고 있지만 어떤 사고가 터졌다 든지 간에 문제가 발생했을 때 책임을 져야 하고 여론의 싸늘한 시선을 볼 수 있다는 여지가 많아 힘들다"라고 토로했다.',
            '지난 11일 광주도시철도공사에 따르면 광주시 산하공기업인 도시철도공사는 각 지역별로 열리는 축제와 행사에 적극 참여해 2호선에 대한 시민 인지도와 호감도를 높일 수 있도록 홍보활동을 펼치고 시민사회와 공공영역이 함께하는 대중교통 혁신플랫폼을 구축해 시민 주도의 대중교통 붐업을 추진한다 밝혔다.',
            '캐나다 유학을 마치고 여행을 하다 사고를 당해 의식불명 상태에 빠진 박준혁씨에 대해 주 로스앤젤레스 총영사관은 행정적인 문제를 돕고 병원비 문제와 한국 이송 문제도 계속 협의하고 있다.',
            '18일 방송된 KBS2 제보자들에서 트로트 가수인 딸의 노래를 곡가 B씨에게 수천만 원을 주고 제작했고, 그 곡을 알리기 위해 몇 년간 열심히 활동을 해왔지만, 몇년간 불러왔던 노래가 유명 가요 방송에서 다른 가수에게 불리는 모습을 봤다며 딸의 억울함을 풀어달라고 절규했다.',
            '10일, 예산군이 저체온증, 동상 등의 한랭 질환 주의보를 발령한다 밝히며, 한랭질환 일일모니터링과 홍보 캠페인 등 경계를 늦추지 않고 있다.',
            '괴산군 사리면 기관·단체협의회회원 20여 명이 28일 사리면사무소에서 괴산읍 신기리 의료폐기물 소각장 설치 반대 및 대한민국 축구종합센터 유치 동참 결의 대회를 열어 "폐기물 소각과정에서 발생하는 발암물질이 군민의 건강을 크게 위협할 것으로 예상되는 만큼 전면 재검토가 이뤄져야 한다"고 주장하고, 선수들의 영양 공급지로서 최적의 조건을 갖추고 있다 "며 "대한민국 축구종합센터가 괴산군에 들어서야 한다 "는 의견을 내세웠다.',
            '26일 완도, 여수, 고흥 등 곳곳에 호우특보가 내려졌다 해제되었지만, 장마전선은 주말에 우리나라로 접근하며 다시 장맛비가 내릴 것이며, 일본 오키나와 부근에서는 태풍이 발달 할 가능성이 있겠다.',
            "청양군은 백제문화체험박물관에 있는 일제에 항거하다 순국하신 최익현 선생의 유품 '최익현 초상'과 최익현 선생이 서울을 떠나 부산으로, 부산에서 대마도로 압송되는 과정을 그린 '최익현 압송도'가 충청남도 유형문화재 제248호, 제249호로 각각 지정됐음을 알렸는데, 이는 올해가 3.1운동 100주년이 되는 해로 더 의미가 있다.",
            '계룡시는 민선5기 일자리 종합 계획을 수립하고 2022년까지 397억 원을 투입해 1만여 개의 일자리를 창출하겠다 밝혔으며, 여성, 노인, 장애인, 청년 등 계층별 일자리 사업을 확대하고 일자리 안내 센터를 통한 취업 교육, 취업 알선 등 맞춤형 고용서비스를 시민들에게 제공할 예정이다.',
            '정부는 올해 10월부터 ‘첩약 급여화 시범사업’을 시행한다는 발표를 하였으나, 이미 2017년과 올 해 10월 각각 한방 추나요법 시범사업과 첩약 급여화 시범사업에 많은 재정이 소요되었다는 등의 우려를 낳고 있으며, 국민 건강에 대해서는 감성적으로 접근해서는 안된다는 의견이 나오고 있다.',
            '지난 22일 부산시가 처음으로 비상저감조치를 발령했지만 공무원 및 공용차량의 비중이 매우 적은 데다 2부제에 참여하지 않아도 처벌할 규정이 없기 때문에 효과가 미미했다.',
            '전남 신안군은 임자도에서 7일부터 이틀간 깡다리 축제를 열어 깡다리요리 및 시식회, 젓갈 담그기, 가요 제 등 다양한 프로그램을 진행하며 관광객들에게는 직거래 판매코너를 운영한다.',
            '오는 12일 SBS 그것이 알고 싶다 에서 희대의 사기꾼 장영자 씨의 약 500억원의 무기명 예금증서에 대한 의혹을 푼다.',
            "김성해 인천 연수구의회 의장이 지난 1년간 연수구의 미래를 책임질 다양한 사업이 차례로 시작되면서 연수구의 교통·교육·경제·문화 인프라가 확충됐으며 구민과 소통하고 공감하는 열정의회가 되도록 최선의 노력을 다하겠다 말하며 '구민의 복리 증진을 위한 조력자 역할에 충실하고자 노력했던 한 해’라고 돌아봤다.",
            '불법 주정차 주민 신고제 단속 규정이 8개 구, 군청별로 달라 운전자들이 혼란을 겪는다는 지적이 있자 대구시는 지자체별로 제각각이던 불법 주정차 주민신고제 운영 표준안을 만들어 신고대상과 정차유예시간을 통일하도록 했다 밝혔으나 행정안전부가 운영하는 안전신문고 애플리케이션을 통한 단속규정만 통일됐을 뿐, 생활불편신고 앱은 기초자치단체마다 다른 규정을 적용토록 해 혼란은 해소되지 않을 것으로 보인다.',
            '당진화력발전소 민간환경감시센터가 석문면 난지섬 일대에 굴과 바지락 등 패류 폐사에 대한 실태파악 조사를 실시한 결과, 주민들이 주요 소득원이었던 굴과 바지락을 채취하지 못해 생계의 어려움을 호소하고 있어 정확한 원인 규명을 통해 관계기관에 원인 규명과 피해에 대한 정밀 조사 및 보상을 촉구할 방침이다.',
            '당진시여성단체협의회가 제24회 평등문화 공감축제 일환으로 서양화, 수묵호, 문인화, 서예, 도예, 조각 등 여러 분야에서 활동하는 여류작가 39인의 다양한 미술작품들이 선보이는 여성미술 초대전 <함께하다 바라보다> 展을 지난1일부터 6일까지 다원갤러리에서 개최했다.',
            '목포시는 부모참여가 보다 확대되고 발전된 형태인 열린 어린이집을 기존의 17개에서 내년 36개소로 점진적으로 선정할 것이라고 발표하였다.',
            "'SBS 인기가요 '에서 민혁,민규, 신은수가 MC로 호흡을 맞추고며  몬스타엑스, SF9, 효민, 이달의 소녀가 컴백했다.",
            '광주예술고등학교가 내년 2020학년도 신입생부터 주요 전공별 내신 성적을 분리해 산출하기로 했으나 타 학교가 분리산출을 곧장 적용한 것과 달리 광주예고는 통합산출을 고수하며 뒤늦게 산출 방식을 바꾼 터라 타지역에 비해 대학 입시에서 불리하게 되었다며 학부모들이 반발하고 있다.',
            '경기도교육청의 도내 여론 조사 결과 응답자 중 59.1%는 현재 사교육을 유지하겠다고 답했으며, 27.1%는 사교육 추가 실시하겠다 로 응답해 총 86.2%가 여름방학 중에도 자녀에게 사교육을 시키겠다고 응답했다.',
            '이날 15일 오후에 방송되는 생방송 오늘 저녁 1110회에서 나 혼자 간다 코너를 통해 국내에서 가장 큰 섬제주도의 숨은 명소인 황우지 해안, 거문오름, 오리백숙 등이 공개 된다.',
            '가수 정준영이 구속된 가운데 2017년 디지털 성범죄는 전년보다 1280건이 늘어난 6465건이 발생하여 불법촬영물로 피해를 당하면 회복하기 어려운 고통을 겪는다는 점에서 보다 엄정한 처벌이 뒤따라야 한다는 주장이 강하다.',
            '화장실에서 벌을 서다 숨진 4살 어린이 사건에서 사망의 원인인 혈종이 생긴 경위에 대해 가족들의 진술을 조사했고 동시에 남은 자녀들에 대한 지원방법을 논의했다.',
            '광주 세계수영 선수권대회 6개 종목 중 국내에서 처음 선보이는 절벽 다이빙에서 유래한 하이다이빙 경기가 다음 달 22일부터 광주시 동구 조선대 축구장 임시 풀에서 사흘간 펼쳐진다.',
            '37회 단양소백산철쭉제가 소백산산신제, 실버가요 제 식전공연 등 50여개의 다채로운 행사를 포함하여 23일~26일까지 단양읍 상상의 거리와 소백산 일원에서 화려한 막을 올린다.',
            '지난 수년간 산림청에서 주요 사업으로 추진하고 있는 치유의 숲 사례지를 둘러보고자 숲속에서 진행되는 체험프로그램을 찾아 밀양, 울산, 부산을 한 바퀴 돌아보다가 산림청에서 추진하는 치유의 숲 프로그램이 전통사찰과 그 주변에서 우리가 무심코 해왔던 행동들과 크게 다르지 않다는 것을 깨달았다.',
            '서울강남경찰서는 지난달 26일 새벽 무면허 음주운전을 벌이다 뺑소니 사고를 낸 배우 손승원씨를 윤창호법으로 불리는 특정범죄가중처벌법상 위험 운전치상 등 혐의로 검찰에 송치했다.',
            '아산시는 미세먼지 저감을 위해 정책기반 부분, 수송 부문, 생활 부문 등 27개 중점과제를 선정하고 179억 원을 투입하기로 했으며 아산시장은 시민이 체감할 수 있는 수송 및 생활부문과 취약계층 중심으로 보다 구체적이고 체계적으로 대책을 마련했다고 말했다.',
            "3일, 김부겸 의원은 '수성 행복드림센터'사업이 생활SOC 복합화사업에 최종 선정된 것에 환영한다 밝혔으며, 한편 도심 밀집 지역 주민들을 위해 건립하는 이 사업에는 2020년부터 3년간 총사업비 227억 원이 투입된다.",
            '배달 대행 업체들의 경쟁이 치열하다 보니 교통 법규를 지키지 않는 배달원이 늘어나고 있어 보다 강력한 단속이 필요하다는 지적이 나온다.',
            '서재헌민주당 부대변인은 이만희 ,이철규의원이 \'2011년 서울시장 보궐선거 때  정보경찰과 나경원 후보의 \'소통창구\' 역할 후  영전과 국회의원자리가  불법개입의 댓가일 수 있다며  선거개입에 대한  의혹을 밝혀야 한다 "고 주장했다.',
            '순천시는 국민적 관심도를 높이고 특별법 제정을 촉구하기 위해 10월 19일 여순사건을 주제로 하는 전국창작가요 제를 여는 방안을 검토중이다.',
            '지난 16일에 방송인 김제동은 MBC FM4U \'굿모닝FM 김제동입니다 \'에서 가수 이효리와 예상치못한 통화 연결을 진행했다.',
            '아산시가 민선 7기 들어 예산의 투명성과 공정성 확보를 위한 변화의 바람을 예고 하여 시는 산학협력사업 지원금에 대한 사후관리 강화와 산학협력사업 평가기준 마련과 평가자문단도 구성해 사업선정과 지원을 보다 체계화 할 예정이다.',
            "제 23회 부천판타스틱영화제는 오는 6일까지 '부천아트벙커B9'에서 ‘NEXT 100’ 프로젝트의 일환으로 마련한 VR 특별전인 '현실을 초월하다 (Beyond Reality)를 열고 있으며 티켓은 현장에서 무료로 받을 수 있다.",
            '17일 이영성 한국일보 편집인에 의하면 세월호 유가족을 향해 논란의 글을 올렸다 삭제한 차명진 전 자유한국당 의원이 서울대 정치학과 79학번 동기인 김학노 교수에게 대화방에서 질타를 받았다.',
            "16일 역사 강사 이다 지가 '김영철의 파워FM'에 출연해 이순신 장군이 명량해전 당시 거북선을 사용하지 않았다고 말해 화제다.",
            '대한민국플라워마켓의 우성용 대표는 화환, 근조 등을 렌털하는 방식의 화훼 공유마켓의 정착과 취약계층에게 일자리를 주고 꽃의 의미와 가치를 지역사회와 나눌 수 있는 기업이 되겠다 다짐했다.',
            '노인 학대 행위자의 70.6%가 자식 혹은 배우자로 주요 학대 행위자가 친족이라는 점을 기억하고 존중받아야 할 노인의 노후를 위해 사회적 관심이 절실하게 필요하다.',
            '제11회 구례 전국여자천하장사 씨름대회에서 구례군청의 조현주 선수가 최희화 선수에게 패해 아쉽게 3위를 차지했으며 최희화 선수는 결승에서 이다현 선수에게 승리하며 2년 연속 천하장사의 자리에 올랐다',
            '당정청은 27일 열린 고위 당정청 협의회에서 제사용품 등의 가격 안정을 꾀하고, 전통시장 가을 축제 및 특산물 할인, 소상공인·저소득층 맞춤형 지원에 주력하는 등 추석 민생안정 대책을 주요 과제로 논의했다.',
            '2006년 생긴 충남장애인부모회 당진지회의 회원으로 활동하다 2012년부터 회장으로 일해온 한숙자씨는 엄마들이 아이들보다 먼저 지치지 않는 것이 가장 중요하다고 말하고 있다.',
            '당진시 농업기술센터는 1.4 대 1의 경쟁률을 보이고, 생력재배 단지 육성, 감자생산 전 과정 기계화 등을 주요 사업으로 하는 2019 새기술 시범사업 대상자를 선정하고, 14기 당진농업기술대학 입학생을 선발 했다.',
            "부산 북구는 WHO에서 주요 폐암 원인이라고 경고한 라돈에 대해 정밀측정기를 구입하여 취약시설 및 기준초과 가정에 대한 정밀검사 서비스를 실시하여 라돈으로부터 안전한 북구 만들기' 프로젝트를 추진한다.",
            '100주년을 맞은 3·1운동 및 상해 임시정부 수립의 숭고한 희생정신과 독립의지에 대하여 우리 후손들이 숨겨졌던 역사 및 인류 문화적 가치와 의미를 재조명해 되새기는 것이 마땅하다 하겠다.']

        non_safe_cnt = 0
        safe_cnt = 0

        for case in cases:
            non_safe_result = kss.split_sentences(case, safe=False)
            safe_result = kss.split_sentences(case, safe=True)

            if len(non_safe_result) == 1:
                non_safe_cnt += 1
            else:
                print(non_safe_result)
            if len(safe_result) == 1:
                safe_cnt += 1

        print(f"`safe=False` accuracy : {non_safe_cnt / len(cases)}")
        print(f"`safe=True` accuracy : {safe_cnt / len(cases)}")


if __name__ == '__main__':
    unittest.main()
